@@ -1,5 +1,7 @@
 #!/bin/sh
-ver="${1-2.1}"
+# SPDX-FileCopyrightText: 2010-2021 Dirk Meyer
+# SPDX-License-Identifier: GPL-2.0-only
+ver="${1-2.2.4}"
 name="miniupnpc-${ver}"
 curl -o "${name}.tar.gz" "http://miniupnp.free.fr/files/${name}.tar.gz"
 tar -xvzf "${name}.tar.gz"
