@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2023 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,7 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_config.c,v 1.254 2019/03/19 09:02:06 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_config.c,v 1.265 2023/07/01 15:03:38 cvs Exp $
  *
  */
 
@@ -187,32 +190,32 @@ static char *print_config_long2(ir_int64 val)
   return text;
 }
 
-/* validate config and warn if password is not encrypted */
-static void checkadminpass2(const char *key, const char *masterpass)
-{
 #ifndef NO_CRYPT
+/* validate config and warn if password is not encrypted */
+static void checkadminpass2(const char *key, const char *adminpass)
+{
   unsigned int err=0;
   unsigned int i;
 
   updatecontext();
 
-  if (!masterpass || strlen(masterpass) < 13U) ++err;
+  if (!adminpass || strlen(adminpass) < 13U) ++err;
 
-  for (i=0; !err && i<strlen(masterpass); ++i) {
-    if (!((masterpass[i] >= 'a' && masterpass[i] <= 'z') ||
-          (masterpass[i] >= 'A' && masterpass[i] <= 'Z') ||
-          (masterpass[i] >= '0' && masterpass[i] <= '9') ||
-          (masterpass[i] == '.') ||
-          (masterpass[i] == '$') ||
-          (masterpass[i] == '/')))
+  for (i=0; !err && i<strlen(adminpass); ++i) {
+    if (!((adminpass[i] >= 'a' && adminpass[i] <= 'z') ||
+          (adminpass[i] >= 'A' && adminpass[i] <= 'Z') ||
+          (adminpass[i] >= '0' && adminpass[i] <= '9') ||
+          (adminpass[i] == '.') ||
+          (adminpass[i] == '$') ||
+          (adminpass[i] == '/')))
       ++err;
   }
 
   if (err) outerror(OUTERROR_TYPE_CRASH,
                     "%s:%ld %s is not encrypted!",
                     current_config, current_line, key);
-#endif /* NO_CRYPT */
 }
+#endif /* NO_CRYPT */
 
 static int config_sorted_check(config_name_t config_name_f)
 {
@@ -439,7 +442,7 @@ static void reset_config_bool(void)
 
 static int config_int_anzahl = 0;
 static config_int_typ config_parse_int[] = {
-{"adddir_min_size",         &gdata.adddir_min_size,         0, 1024, 65000, 0 }, /* NOTRANSLATE */
+{"adddir_min_size",         &gdata.adddir_min_size,         0, 65000, 1024, 0 }, /* NOTRANSLATE */
 {"adminlevel",              &gdata.adminlevel,              1, 5, 1, ADMIN_LEVEL_FULL }, /* NOTRANSLATE */
 {"atfind",                  &gdata.atfind,                  0, 10, 1, 0 }, /* NOTRANSLATE */
 {"autoadd_delay",           &gdata.autoadd_delay,           0, 65000, 1, 0 }, /* NOTRANSLATE */
@@ -526,6 +529,8 @@ static unsigned int report_no_arg(const char *key, const char *text)
 
 static void invalid_args(const char *key, const char *text)
 {
+  if (text == NULL)
+    text = "(null)"; /* NOTRANSLATE */
   outerror(OUTERROR_TYPE_WARN,
            "%s:%ld ignored '%s' because it has invalid args: '%s'",
            current_config, current_line, key, text);
@@ -725,7 +730,10 @@ static unsigned int set_config_string(const char *key, char *text)
                 current_config, current_line, key, text);
        return 0;
      }
+#ifndef NO_CRYPT
      checkadminpass2(key, text);
+#endif /* NO_CRYPT */
+     /* fallthrough */
   case 1:
      convert_to_unix_slash(text);
      break;
@@ -924,6 +932,75 @@ static unsigned int set_config_list(const char *key, char *text)
   return 0;
 }
 
+static size_t add_delimiter(char *val, size_t len)
+{
+  if ( len <= 1 ) {
+    return 0;
+  }
+  return add_snprintf(val + len, maxtextlength - len,
+                      "%s", "," ); /* NOTRANSLATE */
+}
+
+static char *print_config_list(const char *key)
+{
+  ir_cidr_t *cidr;
+  size_t len = 1;
+  int i;
+  unsigned int netmask;
+  char ip6[maxtextlengthshort];
+  char *string;
+  char *val = NULL;
+
+  updatecontext();
+
+  i = config_find_list(key);
+  if (i < 0)
+    return NULL;
+
+  val = mymalloc(maxtextlength);
+  val[0] = '[';
+  val[1] = 0;
+  switch (config_parse_list[i].flags) {
+  case 5:
+    cidr = irlist_add(config_parse_list[i].list, sizeof(ir_cidr_t));
+    for (cidr = irlist_get_head(config_parse_list[i].list);
+         cidr;
+         cidr = irlist_get_next(cidr)) {
+      len += add_delimiter(val, len);
+      my_getnameinfo(ip6, maxtextlengthshort - 1, &(cidr->remote.sa));
+      netmask = 0;
+      if (cidr->family == AF_INET) {
+        netmask = 32;
+      }
+      if (cidr->family == AF_INET6) {
+        netmask = 128;
+      }
+      if (cidr->netmask == netmask) {
+        len += add_snprintf(val + len, maxtextlength - len,
+                            "%s", /* NOTRANSLATE */
+                            ip6);
+      } else {
+        len += add_snprintf(val + len, maxtextlength - len,
+                            "%s/%u", /* NOTRANSLATE */
+                            ip6, cidr->netmask);
+      }
+    }
+    break;
+  default:
+    for (string = irlist_get_head(config_parse_list[i].list);
+         string;
+         string = irlist_get_next(string)) {
+      len += add_delimiter(val, len);
+      len += add_snprintf(val + len, maxtextlength - len,
+                          "\"%s\"", /* NOTRANSLATE */
+                          string);
+    }
+  }
+  len += add_snprintf(val + len, maxtextlength - len,
+                      "%s", "]" ); /* NOTRANSLATE */
+  return val;
+}
+
 static void dump_config_list(void)
 {
   ir_cidr_t *cidr;
@@ -1011,6 +1088,8 @@ static int parse_channel_string(char **cptr, char **part, unsigned int i)
   tptr2 = part[++i];
   if (!tptr2)
     return -1;
+  if (*cptr)
+    return -1;
   *cptr = tptr2;
   return 1;
 }
@@ -1183,7 +1262,7 @@ static void c_autosendpack(const char * UNUSED(key), char *var)
   if (part[0] && part[1]) {
     autoqueue_t *aq;
     aq = irlist_add(&gdata.autoqueue, sizeof(autoqueue_t));
-    rawval = atoi(part[0]);
+    rawval = (unsigned int)strtoul(part[0], NULL, 10);
     if (rawval == XDCC_SEND_LIST) {
       aq->pack = XDCC_SEND_LIST;
     } else {
@@ -1235,6 +1314,7 @@ static void c_channel(const char * UNUSED(key), char *var)
   if (part[0] == NULL)
     return;
 
+  caps(part[0]);
   for (rch = irlist_get_head(&gdata.networks[current_network].channels);
        rch;
        rch = irlist_get_next(rch)) {
@@ -1248,7 +1328,6 @@ static void c_channel(const char * UNUSED(key), char *var)
 
   cptr = irlist_add(&gdata.networks[current_network].channels, sizeof(channel_t));
   cptr->name = part[0];
-  caps(cptr->name);
   if (parse_channel_options(cptr, part[1]) < 0) {
      outerror(OUTERROR_TYPE_WARN,
              "%s:%ld ignored channel '%s' on %s because it has invalid args: '%s'",
@@ -2232,7 +2311,7 @@ static char *p_user_nick(void)
 
 static char *p_version(void)
 {
-  return mystrdup( "iroffer-dinoex " VERSIONLONG ); /* NOTRANSLATE */
+  return mystrdup( "iroffer-dinoex" " " VERSIONLONG ); /* NOTRANSLATE */
 }
 
 static char *p_features(void)
@@ -2240,7 +2319,7 @@ static char *p_features(void)
   char *text;
 
   text = mymalloc(maxtextlength);
-  snprintf(text, maxtextlength, "iroffer-dinoex " VERSIONLONG FEATURES "%s%s",
+  snprintf(text, maxtextlength, "iroffer-dinoex" " " VERSIONLONG FEATURES "%s%s",
            gdata.hideos ? "" : " - ",
            gdata.hideos ? "" : gdata.osstring);
   return text;
@@ -2747,6 +2826,10 @@ char *print_config_key(const char *key)
   if (val != NULL)
     return val;
 
+  val = print_config_list(key);
+  if (val != NULL)
+    return val;
+
   val = print_config_fprint(key);
   if (val != NULL)
     return val;
@@ -2828,6 +2911,7 @@ size_t config_expand(char *buffer, size_t max, int print)
   found = config_expand_search_typ(config_name_bool, buffer, j, &first);
   found += config_expand_search_typ(config_name_int, buffer, j, &first);
   found += config_expand_search_typ(config_name_string, buffer, j, &first);
+  found += config_expand_search_typ(config_name_list, buffer, j, &first);
   found += config_expand_search_typ(print ? config_name_fprint : config_name_func, buffer, j, &first);
   if (found == 0)
     return 0;
@@ -2839,6 +2923,7 @@ size_t config_expand(char *buffer, size_t max, int print)
   config_expand_list_typ(config_name_bool, buffer, j, first);
   config_expand_list_typ(config_name_int, buffer, j, first);
   config_expand_list_typ(config_name_string, buffer, j, first);
+  config_expand_list_typ(config_name_list, buffer, j, first);
   config_expand_list_typ(print ? config_name_fprint : config_name_func, buffer, j, first);
   tostdout("\n");
   return 0;
