@@ -1,15 +1,18 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2018 Dirk Meyer
+ * Copyright (C) 2004-2023 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
  *
  * If you received this file without documentation, it can be
- * downloaded from http://iroffer.net/
+ * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_curl.c,v 1.43 2018/12/20 07:14:05 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_curl.c,v 1.48 2023/07/01 15:03:38 cvs Exp $
  *
  */
 
@@ -76,7 +79,7 @@ void curl_startup(void)
 /* close the curl lib */
 void curl_shutdown(void)
 {
-  if (cm == NULL) {
+  if (cm != NULL) {
     curl_multi_cleanup(cm);
     cm = NULL;
   }
@@ -349,7 +352,7 @@ static unsigned int curl_fetch(const userinput *const u, fetch_curl_t *ft)
   char *vhost;
   CURL *ch;
   CURLcode ces;
-  CURLcode cms;
+  CURLMcode cms;
 
   updatecontext();
 
@@ -604,17 +607,30 @@ void dinoex_dcl(const userinput *const u)
 {
   fetch_curl_t *ft;
   fetch_queue_t *fq;
+#if LIBCURL_VERSION_NUM <= 0x73701
   double dl_total;
   double dl_size;
+#else
+  curl_off_t dl_total;
+  curl_off_t dl_size;
+#endif
   int progress;
 
   updatecontext();
   for (ft = irlist_get_head(&fetch_trans); ft; ft = irlist_get_next(ft)) {
+#if LIBCURL_VERSION_NUM <= 0x73701
     dl_size = 0.0;
     curl_easy_getinfo(ft->curlhandle, CURLINFO_SIZE_DOWNLOAD, &dl_size);
 
     dl_total = 0.0;
     curl_easy_getinfo(ft->curlhandle, CURLINFO_CONTENT_LENGTH_DOWNLOAD, &dl_total);
+#else
+    dl_size = 0;
+    curl_easy_getinfo(ft->curlhandle, CURLINFO_SIZE_DOWNLOAD_T, &dl_size);
+
+    dl_total = 0;
+    curl_easy_getinfo(ft->curlhandle, CURLINFO_CONTENT_LENGTH_DOWNLOAD_T, &dl_total);
+#endif
 
     progress = ((dl_size + 50) * 100) / max2(dl_total, 1);
     a_respond(u, "   %2i  fetch       %-32s   Receiving %d%%", ft->id, ft->name, progress);
@@ -633,16 +649,24 @@ void dinoex_dcld(const userinput *const u)
   fetch_curl_t *ft;
   fetch_queue_t *fq;
   char *effective_url;
+#if LIBCURL_VERSION_NUM <= 0x73701
   double dl_total;
   double dl_size;
   double dl_speed;
   double dl_time;
+#else
+  curl_off_t dl_total;
+  curl_off_t dl_size;
+  curl_off_t dl_speed;
+  curl_off_t dl_time;
+#endif
   int progress;
   int started;
   int left;
 
   updatecontext();
   for (ft = irlist_get_head(&fetch_trans); ft; ft = irlist_get_next(ft)) {
+#if LIBCURL_VERSION_NUM <= 0x73701
     dl_size = 0.0;
     curl_easy_getinfo(ft->curlhandle, CURLINFO_SIZE_DOWNLOAD, &dl_size);
 
@@ -654,6 +678,19 @@ void dinoex_dcld(const userinput *const u)
 
     dl_time = 0.0;
     curl_easy_getinfo(ft->curlhandle, CURLINFO_TOTAL_TIME, &dl_time);
+#else
+    dl_size = 0;
+    curl_easy_getinfo(ft->curlhandle, CURLINFO_SIZE_DOWNLOAD_T, &dl_size);
+
+    dl_total = 0;
+    curl_easy_getinfo(ft->curlhandle, CURLINFO_CONTENT_LENGTH_DOWNLOAD_T, &dl_total);
+
+    dl_speed = 0;
+    curl_easy_getinfo(ft->curlhandle, CURLINFO_SPEED_DOWNLOAD_T, &dl_speed);
+
+    dl_time = 0;
+    curl_easy_getinfo(ft->curlhandle, CURLINFO_TOTAL_TIME_T, &dl_time);
+#endif
 
     effective_url = NULL;
     curl_easy_getinfo(ft->curlhandle, CURLINFO_EFFECTIVE_URL, &effective_url);
