@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2023 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,7 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_http.c,v 1.174 2019/03/19 09:02:07 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_http.c,v 1.183 2023/07/01 15:03:38 cvs Exp $
  *
  */
 
@@ -50,19 +53,19 @@ typedef struct {
 static int http_listen[MAX_VHOSTS];
 static int http_family[MAX_VHOSTS];
 
-static const char *http_header_status =
+static const char * const http_header_status =
 "HTTP/1.1 %u OK\r\n" /* NOTRANSLATE */
 "Date: %s\r\n" /* NOTRANSLATE */
 "Last-Modified: %s\r\n" /* NOTRANSLATE */
-"Server: iroffer-dinoex/" VERSIONLONG "\r\n" /* NOTRANSLATE */
+"Server: " "iroffer-dinoex" "/" VERSIONLONG "\r\n" /* NOTRANSLATE */
 "Content-Type: %s%s\r\n" /* NOTRANSLATE */
 "Connection: close\r\n" /* NOTRANSLATE */
 "Content-Length: %" LLPRINTFMT "u\r\n" /* NOTRANSLATE */;
 
-static const char *http_header_notfound =
+static const char * const http_header_notfound =
 "HTTP/1.1 404 Not Found\r\n" /* NOTRANSLATE */
 "Date: %s\r\n" /* NOTRANSLATE */
-"Server: iroffer-dinoex/" VERSIONLONG "\r\n" /* NOTRANSLATE */
+"Server: " "iroffer-dinoex" "/" VERSIONLONG "\r\n" /* NOTRANSLATE */
 "Content-Type: text/plain\r\n" /* NOTRANSLATE */
 "Connection: close\r\n" /* NOTRANSLATE */
 "Content-Length: 13\r\n" /* NOTRANSLATE */
@@ -70,10 +73,10 @@ static const char *http_header_notfound =
 "Not Found\r\n"
 "\r\n"; /* NOTRANSLATE */
 
-static const char *http_header_forbidden =
+static const char * const http_header_forbidden =
 "HTTP/1.1 403 Forbidden\r\n" /* NOTRANSLATE */
 "Date: %s\r\n" /* NOTRANSLATE */
-"Server: iroffer-dinoex/" VERSIONLONG "\r\n" /* NOTRANSLATE */
+"Server: " "iroffer-dinoex" "/" VERSIONLONG "\r\n" /* NOTRANSLATE */
 "Content-Type: text/plain\r\n" /* NOTRANSLATE */
 "Connection: close\r\n" /* NOTRANSLATE */
 "Content-Length: 13\r\n" /* NOTRANSLATE */
@@ -82,7 +85,7 @@ static const char *http_header_forbidden =
 "\r\n"; /* NOTRANSLATE */
 
 #ifndef WITHOUT_HTTP_ADMIN
-static const char *http_header_admin =
+static const char * const http_header_admin =
 "HTTP/1.1 401 Unauthorized\r\n" /* NOTRANSLATE */
 "Date: %s\r\n" /* NOTRANSLATE */
 "WWW-Authenticate: Basic realm=\"iroffer admin\"\r\n" /* NOTRANSLATE */
@@ -93,7 +96,7 @@ static const char *http_header_admin =
 "Authorization Required\r\n"
 "\r\n"; /* NOTRANSLATE */
 
-static const char *htpp_auth_key = "Basic "; /* NOTRANSLATE */
+static const char * const htpp_auth_key = "Basic "; /* NOTRANSLATE */
 #endif /* WITHOUT_HTTP_ADMIN */
 
 typedef struct {
@@ -110,9 +113,11 @@ static const http_magic_const_t http_magic[] = {
   { "jpg", "image/jpeg" }, /* NOTRANSLATE */
   { "jpeg", "image/jpeg" }, /* NOTRANSLATE */
   { "gif", "image/gif" }, /* NOTRANSLATE */
+  { "svg", "image/svg+xml" }, /* NOTRANSLATE */
   { "css", "text/css" }, /* NOTRANSLATE */
   { "xml", "application/xml" }, /* NOTRANSLATE */
-  { "js", "application/x-javascript" }, /* NOTRANSLATE */
+  { "js", "application/javascript" }, /* NOTRANSLATE */
+  { "json", "application/json" }, /* NOTRANSLATE */
   { NULL, "application/octet-stream" } /* NOTRANSLATE */
 };
 
@@ -137,10 +142,9 @@ static const unsigned char HEX_NIBBLE[] = "0123456789ABCDEF"; /* NOTRANSLATE */
 #ifndef WITHOUT_HTTP_ADMIN
 
 /*
-	BASE 64
-
-	| b64  | b64   | b64   |  b64 |
-	| octect1 | octect2 | octect3 |
+        BASE 64
+        | b64  | b64   | b64   |  b64 |
+        | octect1 | octect2 | octect3 |
 */
 
 static const unsigned char BASE64[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/"; /* NOTRANSLATE */
@@ -240,8 +244,10 @@ static size_t html_encode(char *buffer, size_t max, const char *src)
       if (ch != http_special[i].s_ch)
         continue;
       len = strlen(http_special[i].s_html);
-      if (len > max)
-        len = max;
+      if (len > max) {
+        max = 0;
+        break;
+      }
       strncpy(dest, http_special[i].s_html, len);
       dest += len;
       max -= len;
@@ -496,7 +502,7 @@ static unsigned int h_open_listen(unsigned int i)
   msg = mymalloc(maxtextlength);
   my_getnameinfo(msg, maxtextlength -1, &listenaddr.sa);
   ioutput(OUT_S|OUT_L|OUT_H, COLOR_MAGENTA,
-          "HTTP SERVER waiting for connection on %s",  msg);
+          "HTTP SERVER waiting for connection on %s", msg);
   mydelete(msg);
   return 0;
 }
@@ -675,7 +681,7 @@ static void h_closeconn(http * const h, const char *msg, int errno1)
   h->status = HTTP_STATUS_DONE;
 }
 
-static void h_write_header(http * const h, const char *header)
+static void h_write_header(http * const h, const char * const header)
 {
   char *tempstr;
   char *date;
@@ -745,7 +751,7 @@ static void h_start_sending(http * const h)
             "HTTP '%s' response %ld bytes", h->url, (long)(h->range_end - h->range_start));
 }
 
-static void h_error(http * const h, const char *header)
+static void h_error(http * const h, const char * const header)
 {
   updatecontext();
 
@@ -970,7 +976,7 @@ static void h_accept(unsigned int i)
   h->con.remoteaddr = mystrdup(msg);
   mydelete(msg);
   ioutput(OUT_S|OUT_H, COLOR_MAGENTA,
-          "HTTP connection received from %s",  h->con.remoteaddr);
+          "HTTP connection received from %s", h->con.remoteaddr);
 
   blocked = is_in_badip(&(h->con.remote));
 #if defined(USE_GEOIP) || defined(USE_MAXMINDDB)
@@ -985,13 +991,13 @@ static void h_accept(unsigned int i)
   }
 
   if (irlist_size(&gdata.http_allow) > 0) {
-    if (!verify_cidr(&gdata.http_allow, &remoteaddr)) {
+    if (!verify_cidr(&gdata.http_allow, &(h->con.remote))) {
       h_herror_403(h, "HTTP connection not allowed");
       return;
     }
   }
 
-  if (verify_cidr(&gdata.http_deny, &remoteaddr)) {
+  if (verify_cidr(&gdata.http_deny, &(h->con.remote))) {
     h_herror_403(h, "HTTP connection denied");
     return;
   }
@@ -1177,7 +1183,7 @@ static size_t html_link_option(char *str, size_t size, const char *option, const
 }
 
 static char *html_link_build(const char *css, const char *caption, const char *text,
-				const char *group, unsigned int traffic, const char *order)
+                             const char *group, unsigned int traffic, const char *order)
 {
   char *tempstr;
   size_t len;
@@ -1319,7 +1325,8 @@ static void h_html_main(http * const h)
         ++nogroup;
         ++groups;
         snprintf(tempstr, maxtextlength,
-                 "%s %s", ".", "no group");
+                 "%s %s", ".", /* NOTRANSLATE */
+                 "no group");
         hg = irlist_add(&grplist, sizeof(html_group_t));
         hg->hg_group = "."; /* NOTRANSLATE */
         hg->hg_desc = "no group";
@@ -1417,7 +1424,8 @@ static void h_html_main(http * const h)
     mydelete(tempstr);
   }
   h_respond(h, "<th class=\"head\">%u</th>\n", groups); /* NOTRANSLATE */
-  tlink = h_html_link_group(h, "show all packs in one list", "all packs", "*");
+  tlink = h_html_link_group(h, "show all packs in one list", "all packs",
+                            "*"); /* NOTRANSLATE */
   tempstr = sizestr(0, traffic);
   h_respond(h, "<th class=\"head\">%s [%s]&nbsp;%s</th>\n", /* NOTRANSLATE */
             tlink, tempstr, "complete downloaded" );
@@ -1693,7 +1701,7 @@ static void h_html_index(http * const h)
   (void)add_snprintf(tlabel + len, maxtextlength - len, "%6s %s\n", tempstr, "Traffic this month");
   mydelete(tempstr);
   h_respond(h, "<td title=\"%s\">%s</td>\n", /* NOTRANSLATE */
-            tlabel, "iroffer-dinoex " VERSIONLONG);
+            tlabel, "iroffer-dinoex" " " VERSIONLONG);
   mydelete(tlabel);
 
   tempstr = mymalloc(maxtextlength);
@@ -2274,7 +2282,7 @@ static void h_send(http * const h)
       howmuch = read(h->filedescriptor, gdata.sendbuff, attempt);
       data = (char *)gdata.sendbuff;
     }
-    if (howmuch < 0 && errno != EAGAIN) {
+    if ((howmuch < 0) && (errno != EAGAIN) && (errno != EINTR)) {
       errno2 = errno;
       outerror(OUTERROR_TYPE_WARN, "Can't read data from file '%s': %s",
               h->file, strerror(errno));
@@ -2286,7 +2294,7 @@ static void h_send(http * const h)
 
     h->filepos += howmuch;
     howmuch2 = send(h->con.clientsocket, data, howmuch, MSG_NOSIGNAL);
-    if (howmuch2 < 0 && errno != EAGAIN) {
+    if ((howmuch2 < 0) && (errno != EAGAIN) && (errno != EINTR)) {
       h_closeconn(h, "Connection Lost", errno);
       return;
     }
