@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2021 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,7 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_irc.c,v 1.106 2019/01/20 08:31:56 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_irc.c,v 1.117 2021/09/19 10:10:12 cvs Exp $
  *
  */
 
@@ -295,7 +298,7 @@ static void update_server_welcome(char *line)
       return;
     }
     if (gnetwork->getip_net != gnetwork->net) {
-      /* copy IP from master */
+      /* copy IP from primary network */
       gnetwork->usenatip = 1;
       update_getip_net(gnetwork->getip_net, gdata.networks[gnetwork->getip_net].ourip);
       return;
@@ -347,12 +350,12 @@ unsigned int bind_irc_vhost(int family, int clientsocket)
   if (family != AF_INET6 ) {
     addrlen = sizeof(struct sockaddr_in);
     localaddr.sin.sin_family = AF_INET;
-    localaddr.sin.sin_port = 0;
+    localaddr.sin.sin_port = htons(0);
     e = inet_pton(family, vhost, &(localaddr.sin.sin_addr));
   } else {
     addrlen = sizeof(struct sockaddr_in6);
     localaddr.sin6.sin6_family = AF_INET6;
-    localaddr.sin6.sin6_port = 0;
+    localaddr.sin6.sin6_port = htons(0);
     e = inet_pton(family, vhost, &(localaddr.sin6.sin6_addr));
   }
 
@@ -681,7 +684,7 @@ void irc_resolved(void)
   unsigned int ss;
   int status;
 
-  while ((child = waitpid(-1, &status, WNOHANG)) > 0) {
+  while ((child = waitpid(-1, &status, WNOHANG | WEXITED)) > 0) {
     for (ss=0; ss<gdata.networks_online; ++ss) {
       if (child != gdata.networks[ss].serv_resolv.child_pid)
         continue;
@@ -905,7 +908,8 @@ unsigned int check_ignore(const char *nick, const char *hostmask)
           left < 3600 ? 's' : 'm');
 
   notice(nick,
-         "Auto-ignore activated for %s (%s) lasting %i%c%i%c" ". Further messages will increase duration.",
+         "Auto-ignore activated for %s (%s) lasting %i%c%i%c"
+         ". Further messages will increase duration.",
          nick, hostmask,
          left < 3600 ? left/60 : left/60/60 ,
          left < 3600 ? 'm' : 'h',
@@ -970,6 +974,32 @@ static void irc_server_timeout(void)
   }
 }
 
+static void send_auth_name(const char *auth_name, const char *username, const char *pwd)
+{
+  writeserver(WRITESERVER_NORMAL, "PRIVMSG %s :AUTH %s %s", /* NOTRANSLATE */
+              auth_name, username, pwd);
+  ioutput(OUT_S|OUT_L|OUT_D, COLOR_NO_COLOR,
+          "AUTH send to %s on %s.", gnetwork->auth_name, gnetwork->name);
+}
+
+static void parse_auth_name(const char *pwd)
+{
+  char *work;
+  char *user;
+
+  if (strchr(gnetwork->auth_name, ' ') == NULL) {
+    send_auth_name(gnetwork->auth_name, save_nick(gnetwork->user_nick), pwd );
+    return;
+  }
+
+  work = mystrdup(gnetwork->auth_name);
+  user = strchr(work, ' ');
+  if (user != NULL) {
+    *(user++) = 0;
+  }
+  send_auth_name(work, user, pwd );
+  mydelete(work);
+}
 
 /* try to identify at Nickserv */
 void identify_needed(unsigned int force)
@@ -987,10 +1017,7 @@ void identify_needed(unsigned int force)
   /* wait 1 sec before idetify again */
   gnetwork->next_identify = gdata.curtime + 1;
   if (gnetwork->auth_name != NULL) {
-    writeserver(WRITESERVER_NORMAL, "PRIVMSG %s :AUTH %s %s", /* NOTRANSLATE */
-                gnetwork->auth_name, save_nick(gnetwork->user_nick), pwd);
-    ioutput(OUT_S|OUT_L|OUT_D, COLOR_NO_COLOR,
-            "AUTH send to %s on %s.", gnetwork->auth_name, gnetwork->name);
+    parse_auth_name(pwd);
     return;
   }
   if (gnetwork->login_name != NULL) {
@@ -1053,7 +1080,7 @@ static void irc_001(ir_parseline_t *ipl)
 
   tptr = get_user_modes();
   if (tptr && tptr[0]) {
-    writeserver(WRITESERVER_NOW, "MODE %s %s",
+    writeserver(WRITESERVER_NOW, "MODE %s %s", /* NOTRANSLATE */
                 gnetwork->user_nick, tptr);
   }
 
@@ -1079,7 +1106,7 @@ static void irc_005(ir_parseline_t *ipl)
       break;
     }
 
-    if (!strncmp("PREFIX=(", item, 8)) {
+    if (!strncmp("PREFIX=(", item, 8)) { /* NOTRANSLATE */
       char *ptr = item+8;
       unsigned int pi;
 
@@ -1104,7 +1131,7 @@ static void irc_005(ir_parseline_t *ipl)
       }
     }
 
-    if (!strncmp("CHANMODES=", item, 10)) {
+    if (!strncmp("CHANMODES=", item, 10)) { /* NOTRANSLATE */
       char *ptr = item+10;
       unsigned int ci;
       unsigned int cm;
@@ -1156,7 +1183,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   caps(ipl->part[1]);
 
   /* NOTICE nick */
-  if (!strcmp(ipl->part[1], "NOTICE")) {
+  if (!strcmp(ipl->part[1], "NOTICE")) { /* NOTRANSLATE */
     if (gnetwork->caps_nick && ipl->part[2]) {
       if (!strcmp(caps(ipl->part[2]), gnetwork->caps_nick)) {
         /* nickserv */
@@ -1170,7 +1197,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* PRIVMSG */
-  if (!strcmp(ipl->part[1], "PRIVMSG")) {
+  if (!strcmp(ipl->part[1], "PRIVMSG")) { /* NOTRANSLATE */
 #ifndef WITHOUT_BLOWFISH
     char *line2;
 
@@ -1193,21 +1220,21 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* :server 001  xxxx :welcome.... */
-  if ( !strcmp(ipl->part[1], "001") ) {
+  if ( !strcmp(ipl->part[1], "001") ) { /* NOTRANSLATE */
     irc_001(ipl);
     return;
   }
 
   /* :server 005 xxxx aaa bbb=x ccc=y :are supported... */
-  if ( !strcmp(ipl->part[1], "005") ) {
+  if ( !strcmp(ipl->part[1], "005") ) { /* NOTRANSLATE */
     irc_005(ipl);
     return;
   }
 
   /* :server 401 botnick usernick :No such nick/channel */
-  if ( !strcmp(ipl->part[1], "401") ) {
+  if ( !strcmp(ipl->part[1], "401") ) { /* NOTRANSLATE */
     if (ipl->part[2] && ipl->part[3]) {
-      if (!strcmp(ipl->part[2], "*")) {
+      if (!strcmp(ipl->part[2], "*")) { /* NOTRANSLATE */
         lost_nick(ipl->part[3]);
       }
     }
@@ -1215,9 +1242,9 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* :server 433 old new :Nickname is already in use. */
-  if ( !strcmp(ipl->part[1], "433") ) {
+  if ( !strcmp(ipl->part[1], "433") ) { /* NOTRANSLATE */
     if (ipl->part[2] && ipl->part[3]) {
-      if (!strcmp(ipl->part[2], "*")) {
+      if (!strcmp(ipl->part[2], "*")) { /* NOTRANSLATE */
         ioutput(OUT_S|OUT_L, COLOR_NO_COLOR,
                 "Nickname %s already in use on %s, trying %s%u",
                 ipl->part[3],
@@ -1226,7 +1253,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
                 gnetwork->nick_number);
 
         /* generate new nick and retry */
-        writeserver(WRITESERVER_NORMAL, "NICK %s%u",
+        writeserver(WRITESERVER_NORMAL, "NICK %s%u", /* NOTRANSLATE */
                     get_config_nick(),
                     (gnetwork->nick_number)++);
       }
@@ -1235,7 +1262,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* :server 470 botnick #channel :(you are banned) transfering you to #newchannel */
-  if ( !strcmp(ipl->part[1], "470") ) {
+  if ( !strcmp(ipl->part[1], "470") ) { /* NOTRANSLATE */
     if (ipl->part[2] && ipl->part[3]) {
       outerror(OUTERROR_TYPE_WARN_LOUD,
                "channel on %s: %s", gnetwork->name, strstr(ipl->line, "470"));
@@ -1254,7 +1281,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
 
   /* names list for a channel */
   /* :server 353 our_nick = #channel :nick @nick +nick nick */
-  if ( !strcmp(ipl->part[1], "353") ) {
+  if ( !strcmp(ipl->part[1], "353") ) { /* NOTRANSLATE */
     if (ipl->part[2] && ipl->part[3] && ipl->part[5]) {
       caps(ipl->part[4]);
 
@@ -1272,13 +1299,13 @@ static void ir_parseline2(ir_parseline_t *ipl)
       ioutput(OUT_S|OUT_L|OUT_D, COLOR_NO_COLOR,
               "Got name data for %s which is not a known channel on %s!",
               ipl->part[4], gnetwork->name);
-      writeserver(WRITESERVER_NORMAL, "PART %s", ipl->part[4]);
+      writeserver(WRITESERVER_NORMAL, "PART %s", ipl->part[4]); /* NOTRANSLATE */
     }
     return;
   }
 
   if (gnetwork->lastping != 0) {
-    if (strcmp(ipl->part[1], "PONG") == 0) {
+    if (strcmp(ipl->part[1], "PONG") == 0) { /* NOTRANSLATE */
       lag_message();
       return;
     }
@@ -1286,18 +1313,18 @@ static void ir_parseline2(ir_parseline_t *ipl)
 
 #if PING_SRVR
   /* server ping */
-  if (strncmp(ipl->line, "PING :", 6) == 0) {
+  if (strncmp(ipl->line, "PING ", 5) == 0) { /* NOTRANSLATE */
     if (gdata.debug > 0)
       ioutput(OUT_S, COLOR_NO_COLOR,
               "Server Ping on %s: %s",
               gnetwork->name, ipl->line);
-    writeserver(WRITESERVER_NOW, "PO%s", ipl->line+2);
+    writeserver(WRITESERVER_NOW, "PO%s", ipl->line+2); /* NOTRANSLATE */
     return;
   }
 #endif
 
   /* QUIT */
-  if (strcmp(ipl->part[1], "QUIT") == 0) {
+  if (strcmp(ipl->part[1], "QUIT") == 0) { /* NOTRANSLATE */
     if (gnetwork->caps_nick) {
       nick = ir_get_nickarg(ipl->line);
       if (!strcmp(caps(nick), gnetwork->caps_nick)) {
@@ -1323,7 +1350,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* MODE #channel +x ... */
-  if (strcmp(ipl->part[1], "MODE") == 0) {
+  if (strcmp(ipl->part[1], "MODE") == 0) { /* NOTRANSLATE */
     if (ipl->part[2] && ipl->part[3]) {
       /* find channel */
       for (ch = irlist_get_head(&(gnetwork->channels)); ch; ch = irlist_get_next(ch)) {
@@ -1391,7 +1418,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* JOIN */
-  if (strcmp(ipl->part[1], "JOIN") == 0) {
+  if (strcmp(ipl->part[1], "JOIN") == 0) { /* NOTRANSLATE */
     if (gnetwork->caps_nick && part3a) {
       caps(part3a);
       nick = ir_get_nickarg(ipl->line);
@@ -1413,7 +1440,8 @@ static void ir_parseline2(ir_parseline_t *ipl)
           ch->nextann = gdata.curtime + gdata.waitafterjoin;
           ch->nextmsg = gdata.curtime + gdata.waitafterjoin;
           if (ch->joinmsg) {
-            writeserver(WRITESERVER_NOW, "PRIVMSG %s :%s", ch->name, ch->joinmsg);
+            writeserver(WRITESERVER_NOW, "PRIVMSG %s :%s", /* NOTRANSLATE */
+                        ch->name, ch->joinmsg);
           }
           gnetwork->botstatus = BOTSTATUS_JOINED;
           start_sends();
@@ -1440,7 +1468,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* PART */
-  if (strcmp(ipl->part[1], "PART") == 0) {
+  if (strcmp(ipl->part[1], "PART") == 0) { /* NOTRANSLATE */
     if (gnetwork->caps_nick && part3a) {
       nick = ir_get_nickarg(ipl->line);
       if (!strcmp(caps(nick), gnetwork->caps_nick)) {
@@ -1469,7 +1497,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* NICK */
-  if (strcmp(ipl->part[1], "NICK") == 0) {
+  if (strcmp(ipl->part[1], "NICK") == 0) { /* NOTRANSLATE */
     if (gnetwork->caps_nick && part3a) {
       nick = ir_get_nickarg(ipl->line);
       if (!strcmp(caps(nick), gnetwork->caps_nick)) {
@@ -1497,7 +1525,7 @@ static void ir_parseline2(ir_parseline_t *ipl)
   }
 
   /* KICK */
-  if (strcmp(ipl->part[1], "KICK") == 0) {
+  if (strcmp(ipl->part[1], "KICK") == 0) { /* NOTRANSLATE */
     if (gnetwork->caps_nick && part3a && ipl->part[3]) {
       caps(part3a);
       if (!strcmp(caps(ipl->part[3]), gnetwork->caps_nick)) {
