@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2023 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,7 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_jobs.c,v 1.228 2019/01/20 09:56:37 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_jobs.c,v 1.240 2023/07/01 15:03:38 cvs Exp $
  *
  */
 
@@ -68,22 +71,22 @@ static unsigned long bytes_to_long( const char **str )
   unsigned char ch;
 
   ch = *(*str);
-  result = ch << 24;
+  result = (unsigned long)ch << 24;
   if (ch == 0) return result;
 
   ++(*str);
   ch = *(*str);
-  result |= ch << 16;
+  result |= (unsigned long)ch << 16;
   if (ch == 0) return result;
 
   ++(*str);
   ch = *(*str);
-  result |= ch << 8;
+  result |= (unsigned long)ch << 8;
   if (ch == 0) return result;
 
   ++(*str);
   ch = *(*str);
-  result |= ch;
+  result |= (unsigned long)ch;
   if (ch != 0)
     ++(*str);
   return result;
@@ -139,7 +142,7 @@ static unsigned long base64_to_long( const char **str )
   result = 0L;
   for (i = 0; i < 6; ++i) {
     ch = (unsigned char)(*(*str)++);
-    result |= fish64decode[ ch ] << (i * 6);
+    result |= (unsigned long)fish64decode[ ch ] << (i * 6);
   }
   return result;
 }
@@ -1364,7 +1367,7 @@ int save_unlink(const char *path)
     while (file_not_exits(dest)) {
       snprintf(dest, len, "%s/%s.%03u", gdata.trashcan_dir, file, ++num); /* NOTRANSLATE */
       if (num >= 200) {
-	save_unlink_failed(path, dest);
+        save_unlink_failed(path, dest);
         mydelete(dest);
         return -1;
       }
@@ -1449,13 +1452,16 @@ static void xml_buffer_check(xml_buffer_t *xmlbuf, size_t len)
   xml_buffer_flush(xmlbuf);
 }
 
+#ifndef __clang__
+#pragma GCC diagnostic ignored "-Wstringop-truncation"
+#endif
 static void write_string(xml_buffer_t *xmlbuf, const char *line)
 {
   size_t len;
 
   len = strlen(line);
   xml_buffer_check(xmlbuf, len);
-  strncpy(xmlbuf->buffer+ xmlbuf->len, line, len);
+  strncpy(xmlbuf->buffer + xmlbuf->len, line, len);
   xmlbuf->len += len;
 }
 
@@ -1709,7 +1715,7 @@ static void xdcc_save_xml(void)
   gnetwork = backup;
 
   write_string(xmlbuf, "  <stats>\n"); /* NOTRANSLATE */
-  write_asc_plain(xmlbuf, 4, "version", "iroffer-dinoex " VERSIONLONG ); /* NOTRANSLATE */
+  write_asc_plain(xmlbuf, 4, "version", "iroffer-dinoex" " " VERSIONLONG ); /* NOTRANSLATE */
   tempstr = mymalloc(maxtextlengthshort);
   tempstr = getuptime(tempstr, 1, gdata.startuptime, maxtextlengthshort);
   write_asc_plain(xmlbuf, 4, "uptime", tempstr); /* NOTRANSLATE */
@@ -1883,6 +1889,11 @@ static void irlist_move(irlist_t *dest, irlist_t *src)
   src->tail = NULL;
 }
 
+static int getipfrom( void )
+{
+  return (gdata.getipfromserver || gdata.getipfromupnp);
+}
+
 void a_rehash_prepare(void)
 {
   unsigned int ss;
@@ -1904,7 +1915,7 @@ void a_rehash_prepare(void)
     gdata.networks[ss].r_needtojump = 0;
     gdata.networks[ss].r_connectionmethod = gdata.networks[ss].connectionmethod.how;
     gdata.networks[ss].r_config_nick = NULL;
-    gdata.networks[ss].r_ourip = gdata.getipfromserver || gdata.getipfromupnp ? gdata.networks[ss].ourip : 0;
+    gdata.networks[ss].r_ourip = getipfrom() ? gdata.networks[ss].ourip : 0;
     if (gdata.networks[ss].config_nick)
       gdata.networks[ss].r_config_nick = mystrdup(gdata.networks[ss].config_nick);
     gdata.networks[ss].r_local_vhost = NULL;
@@ -1946,7 +1957,7 @@ void a_rehash_needtojump(const userinput *u)
   for (ss=0; ss<gdata.networks_online; ++ss) {
     gnetwork = &(gdata.networks[ss]);
     /* keep dynamic IP */
-    if (gdata.getipfromserver || gdata.getipfromupnp) {
+    if (getipfrom()) {
       if (gnetwork->r_ourip != 0) {
         gnetwork->ourip = gnetwork->r_ourip;
       }
@@ -2474,7 +2485,7 @@ void expire_options(void)
 
   too_old = gdata.curtime;
   too_old -= 24*60*60; /* 24 hrs */
-  for (ss = gdata.networks_online; ss--; ) {
+  for (ss=0; ss<gdata.networks_online; ++ss) {
     dcc_options = irlist_get_head(&gdata.networks[ss].dcc_options);
     while(dcc_options) {
       if (dcc_options->last_seen >= too_old) {
