@@ -1,15 +1,18 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2020 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
  *
  * If you received this file without documentation, it can be
- * downloaded from http://iroffer.net/
+ * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_misc.c,v 1.362 2019/01/19 15:25:15 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_misc.c,v 1.365 2021/12/16 17:25:52 cvs Exp $
  *
  */
 
@@ -825,7 +828,7 @@ char *get_grouplist_access(const char *nick)
        ch = irlist_get_next(ch)) {
     for (member = irlist_get_head(&ch->members);
          member;
-	 member = irlist_get_next(member)) {
+         member = irlist_get_next(member)) {
       if (strcasecmp(member->nick, nick) != 0)
         continue;
 
@@ -1257,7 +1260,7 @@ void dump_slow_context(void)
   context_t *last;
   ir_uint64 offset;
   unsigned int i;
-  unsigned int show;
+  unsigned int show = 0;
 
   last = NULL;
   lastline = mymalloc(maxtextlength);
@@ -1266,7 +1269,6 @@ void dump_slow_context(void)
     c = &gdata.context_log[(gdata.context_cur_ptr + 1 + i) % MAXCONTEXTS];
     if (c->file == NULL)
       continue;
-    show = 0;
     if (last != NULL) {
       offset = c->tv.tv_sec - last->tv.tv_sec;
       offset *= 1000000;
@@ -1276,17 +1278,18 @@ void dump_slow_context(void)
         show = 1;
       }
     }
+    last = c;
+    if (show == 0)
+      continue;
     snprintf(lastline, maxtextlength,
-             "Trace %3u  %-20s %-16s:%5u  %lu.%06lu",
+             "Trace %3d  %-20s %-16s:%5u  %lu.%06lu",
              i-MAXCONTEXTS+1,
              c->func ? c->func : "UNKNOWN",
              c->file ? c->file : "UNKNOWN",
              c->line,
              (unsigned long)c->tv.tv_sec,
              (unsigned long)c->tv.tv_usec);
-    last = c;
-    if (show)
-      ioutput(OUT_S|OUT_L, COLOR_NO_COLOR, "%s", lastline);
+    ioutput(OUT_S|OUT_L, COLOR_NO_COLOR, "%s", lastline);
   }
   mydelete(lastline);
 }
