@@ -1,15 +1,18 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2023 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
- * available in the README file.
+ * available in the LICENSE file.
  *
  * If you received this file without documentation, it can be
- * downloaded from http://iroffer.net/
+ * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_ruby.c,v 1.55 2019/01/20 07:45:15 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_ruby.c,v 1.62 2023/07/01 15:03:38 cvs Exp $
  *
  * See also:
  * https://ruby-doc.com/docs/ProgrammingRuby/html/ext_ruby.html
@@ -33,6 +36,13 @@
 
 #pragma GCC diagnostic ignored "-Wstrict-prototypes"
 #pragma GCC diagnostic ignored "-Wredundant-decls"
+#pragma GCC diagnostic ignored "-Wunused-parameter"
+#pragma GCC diagnostic ignored "-Wcast-qual"
+#ifdef __clang__
+#pragma GCC diagnostic ignored "-Wgcc-compat"
+#pragma GCC diagnostic ignored "-Wgnu-zero-variadic-macro-arguments"
+#endif
+#undef HAVE_MMAP
 #include "ruby.h"
 #if USE_RUBYVERSION < 19
 #ifndef RSTRING_PTR
@@ -171,27 +181,27 @@ static VALUE cie_new(VALUE rclass)
   return tdata;
 }
 
-static VALUE cie_network(void)
+static VALUE cie_network(VALUE UNUSED(self))
 {
   return rb_str_new(gnetwork->name, strlen(gnetwork->name));
 }
 
-static VALUE cie_inputline(void)
+static VALUE cie_inputline(VALUE UNUSED(self))
 {
   return rb_str_new(cLine, strlen(cLine));
 }
 
-static VALUE cie_added_file(void)
+static VALUE cie_added_file(VALUE UNUSED(self))
 {
   return rb_str_new(cFile, strlen(cFile));
 }
 
-static VALUE cie_added_pack(void)
+static VALUE cie_added_pack(VALUE UNUSED(self))
 {
   return INT2NUM(cPack);
 }
 
-static VALUE cie_hostmask(void)
+static VALUE cie_hostmask(VALUE UNUSED(self))
 {
   VALUE copy;
   char *val;
@@ -205,7 +215,7 @@ static VALUE cie_hostmask(void)
   return copy;
 }
 
-static VALUE cie_mynick(void)
+static VALUE cie_mynick(VALUE UNUSED(self))
 {
   const char *mynick;
 
@@ -213,7 +223,7 @@ static VALUE cie_mynick(void)
   return rb_str_new(mynick, strlen(mynick));
 }
 
-static VALUE cie_nick(void)
+static VALUE cie_nick(VALUE UNUSED(self))
 {
   VALUE copy;
   char *val;
@@ -233,7 +243,7 @@ static VALUE cie_nick(void)
   return copy;
 }
 
-static VALUE cie_channel(void)
+static VALUE cie_channel(VALUE UNUSED(self))
 {
   VALUE copy;
   char *val;
@@ -247,7 +257,7 @@ static VALUE cie_channel(void)
   return copy;
 }
 
-static VALUE cie_message(void)
+static VALUE cie_message(VALUE UNUSED(self))
 {
   VALUE copy;
   char *val;
@@ -495,6 +505,24 @@ static VALUE cie_mode(VALUE UNUSED(module), VALUE rname, VALUE rmsg)
   return Qfalse;
 }
 
+static VALUE cie_usenatip(VALUE UNUSED(module), VALUE rval)
+{
+  char *val;
+
+  if (NIL_P(rval))
+    return Qnil;
+
+  val = rb_obj_as_string_protected(rval);
+  if (!val)
+    return Qnil;
+
+  if (gnetwork->serverstatus != SERVERSTATUS_CONNECTED)
+    return Qfalse;
+
+  update_natip(val);
+  return Qtrue;
+}
+
 static VALUE cie_command(VALUE UNUSED(module), VALUE rmsg)
 {
   char *msg = NULL;
@@ -539,6 +567,7 @@ static void Init_IrofferEvent(void) {
   rb_define_method(cIrofferEvent, "privmsg", cie_privmsg, 2); /* NOTRANSLATE */
   rb_define_method(cIrofferEvent, "warning", cie_warning, 1); /* NOTRANSLATE */
   rb_define_method(cIrofferEvent, "mode", cie_mode, 2); /* NOTRANSLATE */
+  rb_define_method(cIrofferEvent, "usenatip", cie_usenatip, 1); /* NOTRANSLATE */
   rb_define_method(cIrofferEvent, "command", cie_command, -2); /* NOTRANSLATE */
   /* hooks */
   rb_define_method(cIrofferEvent, "on_server", cie_null, 0); /* NOTRANSLATE */
@@ -776,6 +805,7 @@ void startup_myruby(void)
   rb_define_global_function("iroffer_privmsg", cie_privmsg, 2); /* NOTRANSLATE */
   Init_IrofferEvent();
   load_script(gdata.ruby_script);
+  set_signal_handler();
 }
 
 /* cleanup interpreter */
