@@ -1,15 +1,18 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2021 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
  *
  * If you received this file without documentation, it can be
- * downloaded from http://iroffer.net/
+ * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_transfer.c,v 1.70 2019/01/19 15:25:15 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_transfer.c,v 1.75 2021/09/19 10:10:12 cvs Exp $
  *
  */
 
@@ -48,8 +51,8 @@ void t_start_dcc_send(transfer *tr)
                  tr->xpack->st_size);
 
     ioutput(OUT_S|OUT_L|OUT_D, COLOR_YELLOW,
-            "listen on port %d for %s (%s on %s)",
-            tr->con.localport, tr->nick, tr->hostname, gnetwork->name);
+            "listen on port %d for [%d:%s] (%s on %s)",
+            tr->con.localport, tr->id, tr->nick, tr->hostname, gnetwork->name);
   }
   mydelete(dccdata);
   mydelete(sendnamestr);
@@ -195,7 +198,7 @@ void t_notice_transfer(transfer * const tr, const char *msg, unsigned int pack,
   mydelete(tempstr);
 }
 
-/* check ip for matching blacklist and whitelist */
+/* check ip for matching blocklist and accesslist */
 unsigned int t_check_ip_access(transfer *const tr)
 {
   const char *msg;
@@ -244,7 +247,7 @@ static void t_passive(transfer * const tr, ir_uint16 remoteport)
     tr->con.remote.sin6.sin6_family = AF_INET6;
     tr->con.remote.sin6.sin6_port = htons(remoteport);
     retval = inet_pton(AF_INET6, tr->con.remoteaddr, &(tr->con.remote.sin6.sin6_addr));
-    if (retval < 0)
+    if (retval != 1)
       outerror(OUTERROR_TYPE_WARN_LOUD, "Invalid IP: %s", tr->con.remoteaddr);
   }
 
