@@ -1,6 +1,6 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2019 Dirk Meyer
+ * Copyright (C) 2004-2021 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
@@ -9,7 +9,10 @@
  * If you received this file without documentation, it can be
  * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_user.c,v 1.90 2019/01/20 08:31:56 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_user.c,v 1.94 2021/09/20 20:20:30 cvs Exp $
  *
  */
 
@@ -56,7 +59,7 @@ typedef struct {
 
 static const char *type_list[2] = { "NOTICE", "PRIVMSG" }; /* NOTRANSLATE */
 
-const static option_list_t xdcc_option_list[] = {
+static const option_list_t xdcc_option_list[] = {
   { "IPV4",    DCC_OPTION_IPV4,    ~DCC_OPTION_IPV4 }, /* NOTRANSLATE */
   { "IPV6",    DCC_OPTION_IPV6,    ~DCC_OPTION_IPV6 }, /* NOTRANSLATE */
   { "ACTIVE",  DCC_OPTION_ACTIVE , ~DCC_OPTION_ACTIVE }, /* NOTRANSLATE */
@@ -108,19 +111,19 @@ static void send_clientinfo(const char *nick, char *msg2)
     return;
   }
   caps(msg2);
-  if (strncmp(msg2, "PING", 4) == 0) {
+  if (strncmp(msg2, "PING", 4) == 0) { /* NOTRANSLATE */
     notice(nick, IRC_CTCP "CLIENTINFO PING returns the arguments it receives" IRC_CTCP);
     return;
   }
-  if (strncmp(msg2, "DCC", 3) == 0) {
+  if (strncmp(msg2, "DCC", 3) == 0) { /* NOTRANSLATE */
     notice(nick, IRC_CTCP "CLIENTINFO DCC requests a DCC for chatting or file transfer" IRC_CTCP);
     return;
   }
-  if (strncmp(msg2, "VERSION", 7) == 0) {
+  if (strncmp(msg2, "VERSION", 7) == 0) { /* NOTRANSLATE */
     notice(nick, IRC_CTCP "CLIENTINFO VERSION shows information about this client's version" IRC_CTCP);
     return;
   }
-  if (strncmp(msg2, "XDCC", 4) == 0) {
+  if (strncmp(msg2, "XDCC", 4) == 0) { /* NOTRANSLATE */
     notice(nick, IRC_CTCP "CLIENTINFO XDCC LIST|SEND list and DCC file(s) to you" IRC_CTCP);
     return;
   }
@@ -153,6 +156,30 @@ static void log_chat_attempt(privmsginput *pi)
           pi->nick, pi->hostmask, gnetwork->name);
 }
 
+static void command_dcc_chat(privmsginput *pi, int use_ssl)
+{
+  if (verifyshell(&gdata.adminhost, pi->hostmask)) {
+    log_chat_attempt(pi);
+    chat_setup(pi->nick, pi->hostmask, pi->line, use_ssl);
+    return;
+  }
+  if (verifyshell(&gdata.hadminhost, pi->hostmask)) {
+    log_chat_attempt(pi);
+    chat_setup(pi->nick, pi->hostmask, pi->line, use_ssl);
+    return;
+  }
+  if (verifyhost_group(pi->hostmask)) {
+    log_chat_attempt(pi);
+    chat_setup(pi->nick, pi->hostmask, pi->line, use_ssl);
+    return;
+  }
+  notice(pi->nick, "DCC Chat denied from %s", pi->hostmask);
+  ioutput(OUT_S|OUT_L|OUT_D, COLOR_MAGENTA,
+          "DCC CHAT attempt denied from %s (%s on %s)",
+          pi->nick, pi->hostmask, gnetwork->name);
+  return;
+}
+
 static void command_dcc(privmsginput *pi)
 {
   if (strcmp(pi->msg2, "RESUME") == 0) { /* NOTRANSLATE */
@@ -164,26 +191,11 @@ static void command_dcc(privmsginput *pi)
   }
 
   if (strcmp(pi->msg2, "CHAT") == 0) { /* NOTRANSLATE */
-    if (verifyshell(&gdata.adminhost, pi->hostmask)) {
-      log_chat_attempt(pi);
-      setupdccchat(pi->nick, pi->hostmask, pi->line);
-      return;
-    }
-    if (verifyshell(&gdata.hadminhost, pi->hostmask)) {
-      log_chat_attempt(pi);
-      setupdccchat(pi->nick, pi->hostmask, pi->line);
-      return;
-    }
-    if (verifyhost_group(pi->hostmask)) {
-      log_chat_attempt(pi);
-      setupdccchat(pi->nick, pi->hostmask, pi->line);
-      return;
-    }
-    notice(pi->nick, "DCC Chat denied from %s", pi->hostmask);
-    ioutput(OUT_S|OUT_L|OUT_D, COLOR_MAGENTA,
-            "DCC CHAT attempt denied from %s (%s on %s)",
-            pi->nick, pi->hostmask, gnetwork->name);
-    return;
+    command_dcc_chat(pi, 0);
+  }
+
+  if (strcmp(pi->msg2, "SCHAT") == 0) { /* NOTRANSLATE */
+    command_dcc_chat(pi, 1);
   }
 
   if (strcmp(pi->msg2, "SEND") == 0) { /* NOTRANSLATE */
@@ -374,8 +386,8 @@ static unsigned int send_xdcc_file2(const char **bad, privmsginput *pi, unsigned
   if (gdata.nonewcons > gdata.curtime) {
     notice(pi->nick, "** The Owner Has Requested That No New Connections Are Made In The Next %li Minutes%s%s",
            (long)((gdata.nonewcons - gdata.curtime + 1)/60),
-           gdata.nosendmsg ? ", " : "",
-           gdata.nosendmsg ? gdata.nosendmsg : "");
+           gdata.nosendmsg ? ", " : "", /* NOTRANSLATE */
+           gdata.nosendmsg ? gdata.nosendmsg : ""); /* NOTRANSLATE */
     *bad = "(No New Cons)";
     return 1;
   }
@@ -562,14 +574,14 @@ static void log_xdcc_request3(privmsginput *pi, const char *msg)
   const char *part3;
 
   if (msg == NULL) {
-    msg = "";
-    sep = "";
+    msg = ""; /* NOTRANSLATE */
+    sep = ""; /* NOTRANSLATE */
   } else {
     sep = ": ";
   }
   part3 = pi->msg3;
   if (part3 == NULL)
-    part3 = "";
+    part3 = ""; /* NOTRANSLATE */
   ioutput(OUT_S|OUT_L|OUT_D, COLOR_YELLOW,
           "XDCC %s %s%s%s %s (%s on %s)",
           pi->msg2, part3, sep, msg, pi->nick, pi->hostmask, gnetwork->name);
@@ -1148,9 +1160,9 @@ static int botonly_parse(int type, privmsginput *pi)
         return 0;
       notice(pi->nick, IRC_CTCP "PING%s%s%s%s" IRC_CTCP, /* NOTRANSLATE */
              pi->msg2 ? " " : "", /* NOTRANSLATE */
-             pi->msg2 ? pi->msg2 : "",
+             pi->msg2 ? pi->msg2 : "", /* NOTRANSLATE */
              pi->msg3 ? " " : "", /* NOTRANSLATE */
-             pi->msg3 ? pi->msg3 : "");
+             pi->msg3 ? pi->msg3 : ""); /* NOTRANSLATE */
       ioutput(OUT_S|OUT_L|OUT_D, COLOR_YELLOW,
               "[CTCP] %s on %s: PING",
               pi->nick, gnetwork->name);
@@ -1161,9 +1173,10 @@ static int botonly_parse(int type, privmsginput *pi)
   if (test_ctcp(pi->msg1, IRC_CTCP "VERSION")) { /* NOTRANSLATE */
     if (check_ignore(pi->nick, pi->hostmask))
       return 0;
-    notice(pi->nick, IRC_CTCP "VERSION iroffer-dinoex " VERSIONLONG FEATURES ", " "https://iroffer.net/" "%s%s" IRC_CTCP,
+    notice(pi->nick, IRC_CTCP "VERSION" /* NOTRANSLATE */
+           "iroffer-dinoex" " " VERSIONLONG FEATURES ", " "https://iroffer.net/" "%s%s" IRC_CTCP,
            gdata.hideos ? "" : " - ", /* NOTRANSLATE */
-           gdata.hideos ? "" : gdata.osstring);
+           gdata.hideos ? "" : gdata.osstring); /* NOTRANSLATE */
     ioutput(OUT_S|OUT_L|OUT_D, COLOR_YELLOW,
             "[CTCP] %s on %s: VERSION",
             pi->nick, gnetwork->name);
@@ -1223,7 +1236,8 @@ static int botonly_parse(int type, privmsginput *pi)
 
 static void autoqueuef(unsigned int pack, const char *message, privmsginput *pi)
 {
-  const char *format = "** Sending You %s by DCC";
+  const char * const format = "** Sending You %s by DCC";
+  size_t len;
   char *tempstr = NULL;
   const char *msg;
 
@@ -1231,9 +1245,9 @@ static void autoqueuef(unsigned int pack, const char *message, privmsginput *pi)
 
   ++(gnetwork->inamnt[gdata.curtime%INAMNT_SIZE]);
   if (message) {
-    tempstr = mymalloc(strlen(message) + strlen(format) - 1);
-    snprintf(tempstr, strlen(message) + strlen(format) - 1,
-             format, message);
+    len = strlen(message) + strlen(format) - 1;
+    tempstr = mymalloc(len);
+    snprintf(tempstr, len, format, message);
   }
   send_xdcc_file2(&msg, pi, pack, tempstr, NULL, NULL);
   pi->msg2 = mystrdup("AutoSend");
@@ -1596,14 +1610,14 @@ static void privmsgparse2(int type, int decoded, privmsginput *pi)
            "Record:\2(\2%1.1fkB/s\2)\2 "
            "%s%s%s\2=\2iroffer\2=\2",
            irlist_size(&gdata.xdccs),
-           (rtclmsg ? rtclmsg : ""),
-           (rtclmsg ? " " : ""),
+           (rtclmsg ? rtclmsg : ""), /* NOTRANSLATE */
+           (rtclmsg ? " " : ""), /* NOTRANSLATE */
            tempstr2,
            irlist_size(&gdata.trans), gdata.slotsmax,
            irlist_size(&gdata.mainqueue), gdata.queuesize,
            gdata.record,
            gdata.creditline ? "Note:\2(\2" : "",
-           gdata.creditline ? gdata.creditline : "",
+           gdata.creditline ? gdata.creditline : "", /* NOTRANSLATE */
            gdata.creditline ? "\2)\2 " : "");
 
     mydelete(tempstr2);
