@@ -1,15 +1,18 @@
 /*
  * by Dirk Meyer (dinoex)
- * Copyright (C) 2004-2018 Dirk Meyer
+ * Copyright (C) 2004-2023 Dirk Meyer
  *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
  *
  * If you received this file without documentation, it can be
- * downloaded from http://iroffer.net/
+ * downloaded from https://iroffer.net/
  *
- * $Id: dinoex_utilities.c,v 1.130 2018/12/20 07:14:05 cvs Exp $
+ * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
+ * $Id: dinoex_utilities.c,v 1.135 2023/07/01 15:03:38 cvs Exp $
  *
  */
 
@@ -130,7 +133,7 @@ const char *save_nick(const char * nick)
 }
 
 /* verify a password against the stored hash */
-unsigned int verifypass2(const char *masterpass, const char *testpass)
+unsigned int verifypass2(const char *adminpass, const char *testpass)
 {
 #ifndef NO_CRYPT
   char *pwout;
@@ -138,22 +141,22 @@ unsigned int verifypass2(const char *masterpass, const char *testpass)
 
   updatecontext();
 
-  if (!masterpass || !testpass)
+  if (!adminpass || !testpass)
     return 0;
 
 #ifndef NO_CRYPT
-  if ((strlen(masterpass) < 13U) ||
+  if ((strlen(adminpass) < 13U) ||
       (strlen(testpass) < 5U) ||
       (strlen(testpass) > 59U))
     return 0;
 
-  pwout = crypt(testpass, masterpass);
-  if (strcmp(pwout, masterpass)) return 0;
+  pwout = crypt(testpass, adminpass);
+  if (strcmp(pwout, adminpass)) return 0;
 #else /* NO_CRYPT */
-  if (!masterpass || !testpass)
+  if (!adminpass || !testpass)
     return 0;
 
-  if (strcmp(testpass, masterpass)) return 0;
+  if (strcmp(testpass, adminpass)) return 0;
 #endif /* NO_CRYPT */
 
   /* allow */
@@ -531,6 +534,7 @@ void removenonprintablefile(char *str)
     case ' ':
       if (gdata.spaces_in_filenames)
         break;
+      /* fallthrough */
     case '|':
     case ':':
     case '?':
@@ -1078,26 +1082,26 @@ void irlist_sort2(irlist_t *list, int (*cmpfunc)(const void *a, const void *b))
           /* p is empty; e must come from q. */
           e = q;
           q = irlist_get_next(q);
-	  irlist_remove(list, e);
+          irlist_remove(list, e);
           qsize--;
         } else if (qsize == 0 || !q) {
           /* q is empty; e must come from p. */
           e = p;
           p = irlist_get_next(p);
-	  irlist_remove(list, e);
+          irlist_remove(list, e);
           psize--;
         } else if (cmpfunc(p, q) <= 0) {
           /* First element of p is lower (or same);
           * e must come from p. */
           e = p;
           p = irlist_get_next(p);
-	  irlist_remove(list, e);
+          irlist_remove(list, e);
           psize--;
         } else {
           /* First element of q is lower; e must come from q. */
           e = q;
           q = irlist_get_next(q);
-	  irlist_remove(list, e);
+          irlist_remove(list, e);
           qsize--;
         }
 
