@@ -1,17 +1,21 @@
 /*
  * iroffer by David Johnson (PMG)
  * Copyright (C) 1998-2005 David Johnson
- * 
+ *
  * By using this file, you agree to the terms and conditions set
  * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
- * 
+ *
  * If you received this file without documentation, it can be
  * downloaded from http://iroffer.org/
- * 
+ *
+ * SPDX-FileCopyrightText: 1998-2005 David Johnson
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
  * @(#) iroffer_admin.c 1.215@(#)
  * pmg@wellington.i202.centerclick.org|src/iroffer_admin.c|20051123201143|48668
- * 
+ *
  */
 
 /* include the headers */
@@ -39,10 +43,7 @@ static void u_redraw(const userinput * const u);
 static void u_delhist(const userinput * const u);
 static void u_info(const userinput * const u);
 static void u_psend(const userinput * const u);
-static void u_quit(const userinput * const u);
 static void u_status(const userinput * const u);
-static void u_chatme(const userinput * const u);
-static void u_chatl(const userinput * const u);
 static void u_rehash(const userinput * const u);
 static void u_botinfo(const userinput * const u);
 static void u_ignl(const userinput * const u);
@@ -211,11 +212,11 @@ static const userinput_parse_t userinput_parse[] = {
 {6,5,method_allow_all,a_cleargets,     "CLEARGETS",NULL,"Clears download counters for each pack and total sent and uptime"},
 {6,5,method_console,  u_redraw,        "REDRAW",NULL,"Redraws the Screen"},
 {6,5,method_console,  u_delhist,       "DELHIST",NULL,"Deletes console history"},
-{6,1,method_dcc,      u_quit,          "QUIT",NULL,"Close this DCC chat"},
-{6,1,method_dcc,      u_quit,          "EXIT",NULL,"Close this DCC chat"},
-{6,1,method_dcc,      u_quit,          "LOGOUT",NULL,"Close this DCC chat"},
-{6,1,method_msg,      u_chatme,        "CHATME",NULL,"Sends you a DCC Chat Request"},
-{6,1,method_allow_all,u_chatl,         "CHATL",NULL,"Lists DCC chat information"},
+{6,1,method_dcc,      a_quit,          "QUIT",NULL,"Close this DCC chat"},
+{6,1,method_dcc,      a_quit,          "EXIT",NULL,"Close this DCC chat"},
+{6,1,method_dcc,      a_quit,          "LOGOUT",NULL,"Close this DCC chat"},
+{6,1,method_msg,      a_chatme,        "CHATME","[options]","Sends you a DCC Chat Request"},
+{6,1,method_allow_all,a_chatl,         "CHATL",NULL,"Lists DCC chat information"},
 {6,5,method_allow_all,a_closec,        "CLOSEC","[id]","Closes DCC chat <id>"},
 {6,5,method_console,  u_debug,         "DEBUG","x","Set debugging level to <x>"},
 {6,5,method_allow_all,a_config,        "CONFIG","key value","Set config variable <key> to <value>"},
@@ -347,7 +348,7 @@ void u_parseit(userinput * const u) {
    }
 
 static const char *expand_args_shutdown[] = {
-  "NOW", "DELAYED", "CANCEL", NULL
+  "NOW", "DELAYED", "CANCEL", NULL /* NOTRANSLATE */
 };
 
 static size_t u_expand_list(char *buffer, size_t max, const char **list)
@@ -380,7 +381,7 @@ static size_t u_expand_list(char *buffer, size_t max, const char **list)
       tostdout(",");
     tostdout(" %s", list[i]);
   }
-  tostdout("\n");
+  tostdout("\n"); /* NOTRANSLATE */
   return 0;
 }
 
@@ -462,7 +463,7 @@ static size_t u_expand_command2(char *cmd)
   }
   if (found == 0) {
     tostdout("** User Command Not Recognized, try \"HELP\"");
-    tostdout("\n");
+    tostdout("\n"); /* NOTRANSLATE */
     return 0;
   }
   if (found == 1) {
@@ -485,7 +486,7 @@ static size_t u_expand_command2(char *cmd)
       tostdout(",");
     tostdout(" %s", userinput_parse[i].command);
   }
-  tostdout("\n");
+  tostdout("\n"); /* NOTRANSLATE */
   return 0;
 }
 
@@ -675,7 +676,7 @@ void u_xdl_head(const userinput * const u)
            len = strlen(tempstr);
          }
        
-       u_respond(u,"%s",tempstr);
+       u_respond(u, "%s", tempstr); /* NOTRANSLATE */
        
        
        for (i=0,xdccsent=0; i<XDCC_SENT_SIZE; i++)
@@ -704,7 +705,7 @@ void u_xdl_head(const userinput * const u)
            len = strlen(tempstr);
          }
        
-       u_respond(u,"%s",tempstr);
+       u_respond(u, "%s", tempstr); /* NOTRANSLATE */
        
        a_respond(u, "\2**\2 To request a file, type \"/MSG %s XDCC SEND x\" \2**\2",
                  mynick);
@@ -1181,111 +1182,17 @@ static void u_psend(const userinput * const u)
   
 }
 
-static void u_quit(const userinput * const u)
-{
-  updatecontext();
-  
-  ioutput(OUT_S|OUT_L, COLOR_MAGENTA, "DCC CHAT: QUIT");
-  u_respond(u,"Bye.");
-  
-  shutdowndccchat(u->chat,1);
-  /* caller deletes */
-}
-
 static void u_status(const userinput * const u) {
    char *tempstr = mymalloc(maxtextlength);
    
    updatecontext();
    
    getstatusline(tempstr,maxtextlength);
-   u_respond(u,"%s",tempstr);
+   u_respond(u, "%s", tempstr); /* NOTRANSLATE */
    
    mydelete(tempstr);
    }
 
-static void u_chatme(const userinput * const u) {
-   
-   updatecontext();
-   
-   u_respond(u,"Sending You A DCC Chat Request");
-   
-   if (setupdccchatout(u->snick, u->hostmask, NULL))
-      u_respond(u,"[Failed to listen, try again]");
-   
-   
-   }
-
-static void u_chatl(const userinput * const u)
-{
-  char *tempstr;
-  dccchat_t *chat;
-  int count;
-  
-  updatecontext();
-  
-  if (!gdata.num_dccchats)
-    {
-      u_respond(u,"No Active DCC Chats");
-      return;
-    }
-  
-  for (chat = irlist_get_head(&gdata.dccchats), count = 1;
-       chat;
-       chat = irlist_get_next(chat), count++)
-    {
-      if (chat->status == DCCCHAT_UNUSED)
-        {
-          continue;
-        }
-      
-      a_respond(u, "DCC CHAT %u:", count);
-      switch (chat->status)
-        {
-        case DCCCHAT_LISTENING:
-          u_respond(u,"  Chat sent to %s. Waiting for inbound connection.",
-                    chat->nick);
-          break;
-          
-        case DCCCHAT_CONNECTING:
-          u_respond(u,"  Chat received from %s. Waiting for outbound connection.",
-                    chat->nick);
-          break;
-          
-        case DCCCHAT_AUTHENTICATING:
-          u_respond(u,"  Chat established with %s. Waiting for password.",
-                    chat->nick);
-          break;
-          
-        case DCCCHAT_CONNECTED:
-          u_respond(u,"  Chat established with %s.",
-                    chat->nick);
-          break;
-          
-        case DCCCHAT_UNUSED:
-        default:
-          outerror(OUTERROR_TYPE_WARN_LOUD,
-                   "Unexpected dccchat state %u", chat->status);
-          break;
-        }
-      
-      tempstr = mymalloc(maxtextlengthshort);
-      
-      user_getdatestr(tempstr, chat->con.connecttime, maxtextlengthshort);
-      u_respond(u,"  Connected at %s",tempstr);
-      
-      user_getdatestr(tempstr, chat->con.connecttime, maxtextlengthshort);
-      u_respond(u,"  Last contact %s",tempstr);
-      
-      mydelete(tempstr);
-      
-      a_respond(u, "  Local: %s, Remote: %s",
-                chat->con.localaddr,
-                chat->con.remoteaddr);
-    }
-  
-  return;
-}
-
 static void u_rehash(const userinput * const u) {
    
    /* other variables */
@@ -1436,7 +1343,7 @@ static void u_botinfo(const userinput * const u) {
    
    u_respond(u,"BotInfo:");
 
-   a_respond(u, "iroffer-dinoex " VERSIONLONG FEATURES ", " "https://iroffer.net/" "%s%s",
+   a_respond(u, "iroffer-dinoex" " " VERSIONLONG FEATURES ", " "https://iroffer.net/" "%s%s",
              gdata.hideos ? "" : " - ",
              gdata.hideos ? "" : gdata.osstring);
 
@@ -1561,7 +1468,7 @@ static void u_botinfo(const userinput * const u) {
                         text_pformat(ch->flags));
              }
            
-           a_respond(u, "%s", tempstr);
+           a_respond(u, "%s", tempstr); /* NOTRANSLATE */
            
            ch = irlist_get_next(ch);
          }
@@ -1592,22 +1499,27 @@ static void u_botinfo(const userinput * const u) {
    for (ii=0; ii<NUMBER_TRANSFERLIMITS; ii++)
      {
        char *tempstr2 = mymalloc(maxtextlength);
+       char *used;
+       char *limit;
        
        user_getdatestr(tempstr2, gdata.transferlimits[ii].ends, maxtextlength);
+       used = sizestr(0, gdata.transferlimits[ii].used);
        
        if (gdata.transferlimits[ii].limit)
          {
-           u_respond(u, "transferlimit: %7s (ends %s): used %" LLPRINTFMT "uMB, limit %" LLPRINTFMT "uMB",
+           limit = sizestr(0, gdata.transferlimits[ii].limit);
+           u_respond(u, "transferlimit: %7s (ends %s): used %s, " "limit %s",
                      transferlimit_type_to_string(ii), tempstr2,
-                     gdata.transferlimits[ii].used / 1024 / 1024,
-                     gdata.transferlimits[ii].limit / 1024 / 1024);
+                     used, limit);
+           mydelete(limit);
          }
        else
          {
-           u_respond(u, "transferlimit: %7s (ends %s): used %" LLPRINTFMT "uMB, limit unlimited",
-                     transferlimit_type_to_string(ii),tempstr2 ,
-                     gdata.transferlimits[ii].used / 1024 / 1024);
+           u_respond(u, "transferlimit: %7s (ends %s): used %s, " "unlimited",
+                     transferlimit_type_to_string(ii), tempstr2 ,
+                     used);
          }
+       mydelete(used);
        mydelete(tempstr2);
      }
    
@@ -1983,20 +1895,20 @@ static void u_shutdown(const userinput * const u) {
        caps(u->arg1);
      }
    
-   if (!u->arg1 || (strcmp(u->arg1,"NOW") && strcmp(u->arg1,"DELAYED") && strcmp(u->arg1,"CANCEL")) ) {
+   if (!u->arg1 || (strcmp(u->arg1, "NOW") && strcmp(u->arg1, "DELAYED") && strcmp(u->arg1, "CANCEL")) ) { /* NOTRANSLATE */
       u_respond(u,"Usage: SHUTDOWN <now|delayed|cancel>");
       return;
       }
    
-   if (!strcmp(u->arg1,"NOW")) {
+   if (!strcmp(u->arg1, "NOW")) { /* NOTRANSLATE */
       gdata.needsshutdown = 1;
       }
-   else if (!strcmp(u->arg1,"DELAYED")) {
+   else if (!strcmp(u->arg1, "DELAYED")) { /* NOTRANSLATE */
       u_respond(u,"Delayed shutdown activated, iroffer will shutdown once there are no active transfers");
       u_respond(u,"To cancel the delayed shutdown, issue \"SHUTDOWN CANCEL\"");
       gdata.delayedshutdown=1;
       }
-   else if (!strcmp(u->arg1,"CANCEL")) {
+   else if (!strcmp(u->arg1, "CANCEL")) { /* NOTRANSLATE */
       u_respond(u,"Delayed shutdown canceled");
       gdata.delayedshutdown=0;
       }
@@ -2196,7 +2108,7 @@ void u_listdir(const userinput * const u, const char *dir)
   
   while ((f = readdir(d)))
     {
-      if (strcmp(f->d_name,".") && strcmp(f->d_name,".."))
+      if (strcmp(f->d_name, ".") && strcmp(f->d_name, "..")) /* NOTRANSLATE */
         {
           irlist_add_string(&dirlist, f->d_name);
         }
@@ -2382,7 +2294,7 @@ static void u_chanl(const userinput * const u)
                    "%s%s ", member->prefixes, member->nick);
           if (!((j+1)%USERS_PER_CHAN_LINE))
             {
-              u_respond(u,"%s",tempstr);
+              u_respond(u, "%s", tempstr); /* NOTRANSLATE */
               tempstr[0] = '\0';
             }
           
@@ -2392,7 +2304,7 @@ static void u_chanl(const userinput * const u)
       
       if (j%USERS_PER_CHAN_LINE)
         {
-          u_respond(u,"%s",tempstr);
+          u_respond(u, "%s", tempstr); /* NOTRANSLATE */
         }
       
       a_respond(u, "%s: %i %s", ch->name, j, j!=1 ? "users" : "user");
