@@ -1,17 +1,21 @@
 /*
- * iroffer by David Johnson (PMG) 
- * Copyright (C) 1998-2005 David Johnson 
- * 
+ * iroffer by David Johnson (PMG)
+ * Copyright (C) 1998-2005 David Johnson
+ *
  * By using this file, you agree to the terms and conditions set
- * forth in the GNU General Public License.  More information is    
+ * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
- * 
+ *
  * If you received this file without documentation, it can be
  * downloaded from http://iroffer.org/
- * 
+ *
+ * SPDX-FileCopyrightText: 1998-2005 David Johnson
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
  * @(#) iroffer_main.c 1.245@(#)
  * pmg@wellington.i202.centerclick.org|src/iroffer_main.c|20050313225819|23935
- * 
+ *
  */
 
 /* include the headers */
@@ -42,12 +46,10 @@ static void mainloop(void);
 /* main */
 int
 #ifdef __GNUC__
-#if !defined(__STDC_VERSION__) || __STDC_VERSION__ != 199901L
-#if !defined(__STDC_VERSION__) || __STDC_VERSION__ != 201112L
+#if !defined(__STDC_VERSION__) || __STDC_VERSION__ < 199901L
 __attribute__ ((noreturn))
 #endif
 #endif
-#endif
 main(int argc, char *const *argv) {
    
    initvars();
@@ -336,7 +338,7 @@ static void mainloop (void) {
       
       irc_perform(changesec);
       l_perform(changesec);
-      chat_perform();
+      chat_perform(changesec);
       t_perform(changesec, changequartersec);
 #ifndef WITHOUT_TELNET
       telnet_perform();
@@ -545,7 +547,7 @@ static void mainloop (void) {
                 const char *servname = gnetwork->curserveractualname ? gnetwork->curserveractualname : gnetwork->curserver.hostname;
                 size_t     len       = 6 + strlen(servname);
                 char       *tempstr3 = mymalloc(len + 1);
-                snprintf(tempstr3, len + 1, "PING %s\n", servname);
+                snprintf(tempstr3, len + 1, "PING %s\n", servname); /* NOTRANSLATE */
                 writeserver_ssl(tempstr3, len);
                 if (gdata.debug > 0)
                   {
@@ -864,7 +866,7 @@ static void mainloop (void) {
            /* try to regain nick */
            if (!gnetwork->user_nick || strcmp(get_config_nick(), gnetwork->user_nick))
              {
-               writeserver(WRITESERVER_NORMAL, "NICK %s", get_config_nick());
+               writeserver(WRITESERVER_NORMAL, "NICK %s", get_config_nick()); /* NOTRANSLATE */
              }
            } /* networks */
          gnetwork = NULL;
@@ -930,7 +932,7 @@ static void mainloop (void) {
                           number_of_pack(gdata.md5build.xpack), (long)howmuch);
                 }
               
-              if ((howmuch < 0) && (errno != EAGAIN))
+              if ((howmuch < 0) && (errno != EAGAIN) && (errno != EINTR))
                 {
                   outerror(OUTERROR_TYPE_WARN, "MD5: [Pack %u] Can't read data from file '%s': %s",
                            number_of_pack(gdata.md5build.xpack),
@@ -996,14 +998,7 @@ static void mainloop (void) {
       
       if (gdata.exiting && has_closed_servers()) {
          
-         for (chat = irlist_get_head(&gdata.dccchats);
-              chat;
-              chat = irlist_delete(&gdata.dccchats,chat))
-           {
-             writedccchat(chat, 0, "iroffer exited, Closing DCC Chat\n");
-             shutdowndccchat(chat,1);
-           }
-         
+         chat_shutdown_all();
          mylog("iroffer exited\n\n");
          
          exit_iroffer(0);
