@@ -1,17 +1,21 @@
 /*
- * iroffer by David Johnson (PMG) 
- * Copyright (C) 1998-2005 David Johnson 
- * 
+ * iroffer by David Johnson (PMG)
+ * Copyright (C) 1998-2005 David Johnson
+ *
  * By using this file, you agree to the terms and conditions set
- * forth in the GNU General Public License.  More information is    
+ * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
- * 
+ *
  * If you received this file without documentation, it can be
  * downloaded from http://iroffer.org/
- * 
+ *
+ * SPDX-FileCopyrightText: 1998-2005 David Johnson
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
  * @(#) iroffer_misc.c 1.251@(#)
  * pmg@wellington.i202.centerclick.org|src/iroffer_misc.c|20051123201144|15577
- * 
+ *
  */
 
 /* include the headers */
@@ -28,6 +32,7 @@
 #include "dinoex_jobs.h"
 #include "dinoex_http.h"
 #include "dinoex_main.h"
+#include "dinoex_chat.h"
 #include "dinoex_misc.h"
 
 
@@ -216,7 +221,7 @@ static int connectirc (server_t *tserver) {
      {
        /* child */
        child_resolver(family);
-       sleep(60);
+       sleep(5);
        _exit(0);
      }
    
@@ -285,7 +290,7 @@ void initirc(void)
             }
         }
       tempstr[j] = '\0';
-      writeserver(WRITESERVER_NOW, "%s", tempstr);
+      writeserver(WRITESERVER_NOW, "%s", tempstr); /* NOTRANSLATE */
       
       mydelete(tempstr);
       
@@ -293,26 +298,26 @@ void initirc(void)
     }
       
    if (gnetwork->connectionmethod.how == how_wingate) {
-      writeserver(WRITESERVER_NOW, "%s %u",
+      writeserver(WRITESERVER_NOW, "%s %u", /* NOTRANSLATE */
                   gnetwork->curserver.hostname, gnetwork->curserver.port);
       }
 
    if (gnetwork->curserver.password)
      {
-       writeserver(WRITESERVER_NOW, "PASS %s", gnetwork->curserver.password);
+       writeserver(WRITESERVER_NOW, "PASS %s", gnetwork->curserver.password); /* NOTRANSLATE */
      }
-   writeserver(WRITESERVER_NOW, "NICK %s", get_config_nick());
-   writeserver(WRITESERVER_NOW, "USER %s 32 . :%s",
+   writeserver(WRITESERVER_NOW, "NICK %s", get_config_nick()); /* NOTRANSLATE */
+   writeserver(WRITESERVER_NOW, "USER %s 32 . :%s", /* NOTRANSLATE */
                gdata.loginname, gdata.user_realname);
    
    if (gnetwork->connectionmethod.how == how_bnc) {
-      writeserver(WRITESERVER_NOW, "PASS %s",
+      writeserver(WRITESERVER_NOW, "PASS %s", /* NOTRANSLATE */
                   gnetwork->connectionmethod.password);
       if (gnetwork->connectionmethod.vhost) {
-         writeserver(WRITESERVER_NOW, "VIP %s",
+         writeserver(WRITESERVER_NOW, "VIP %s", /* NOTRANSLATE */
                      gnetwork->connectionmethod.vhost);
          }
-      writeserver(WRITESERVER_NOW, "CONN %s %d",
+      writeserver(WRITESERVER_NOW, "CONN %s %d", /* NOTRANSLATE */
                   gnetwork->curserver.hostname, gnetwork->curserver.port);
       }
    
@@ -320,7 +325,7 @@ void initirc(void)
   tptr = irlist_get_head(&(gnetwork->server_join_raw));
   while(tptr)
     {
-      writeserver(WRITESERVER_NORMAL, "%s", tptr);
+      writeserver(WRITESERVER_NORMAL, "%s", tptr); /* NOTRANSLATE */
       tptr = irlist_get_next(tptr);
     }
    
@@ -580,7 +585,7 @@ void sendserver(void)
 void pingserver(void) {
    updatecontext();
 
-   writeserver(WRITESERVER_NOW, "PING %s",
+   writeserver(WRITESERVER_NOW, "PING %s", /* NOTRANSLATE */
                gnetwork->curserveractualname ? gnetwork->curserveractualname : gnetwork->curserver.hostname);
    }
 
@@ -702,7 +707,7 @@ void gobackground(void) {
    /* background continues... */
    
 /*   umask(0); */
-   s = open("/dev/null", O_RDWR); /* stdin */
+   s = open("/dev/null", O_RDWR); /* stdin */ /* NOTRANSLATE */
    dup(s);                        /* stdout */
    dup(s);                        /* stderr */
    
@@ -1031,17 +1036,17 @@ void joinchannel(channel_t *c)
 
   if (c->key)
     {
-      writeserver(WRITESERVER_NORMAL, "JOIN %s %s", c->name, c->key);
+      writeserver(WRITESERVER_NORMAL, "JOIN %s %s", c->name, c->key); /* NOTRANSLATE */
     }
   else
     {
-      writeserver(WRITESERVER_NORMAL, "JOIN %s", c->name);
+      writeserver(WRITESERVER_NORMAL, "JOIN %s", c->name); /* NOTRANSLATE */
     }
   
   tptr = irlist_get_head(&(gnetwork->channel_join_raw));
   while(tptr)
     {
-      writeserver(WRITESERVER_NORMAL, "%s", tptr);
+      writeserver(WRITESERVER_NORMAL, "%s", tptr); /* NOTRANSLATE */
       tptr = irlist_get_next(tptr);
     }
   
@@ -1077,7 +1082,7 @@ void shutdowniroffer(void) {
            chat = irlist_delete(&gdata.dccchats,chat))
         {
           writedccchat(chat, 0, "iroffer exited (shutdown), Closing DCC Chat\n");
-          shutdowndccchat(chat,1);
+          chat_shutdown(chat, 1);
         }
       
       mylog("iroffer exited (shutdown)\n\n");
@@ -1128,7 +1133,9 @@ void shutdowniroffer(void) {
            tempstr2 = mymalloc(maxtextlengthshort);
            getuptime(tempstr2, 1, gdata.startuptime, maxtextlengthshort);
            snprintf(msg, maxtextlength,
-                    "QUIT :iroffer-dinoex " VERSIONLONG "%s%s - running %s",
+                    "QUIT :%s" /* NOTRANSLATE */
+                    "%s%s - running %s",
+                    "iroffer-dinoex" " " VERSIONLONG,
                     gdata.hideos ? "" : " - ",
                     gdata.hideos ? "" : gdata.osstring,
                     tempstr2);
@@ -1137,9 +1144,9 @@ void shutdowniroffer(void) {
        else
          {
            if (strcmp(gdata.quit_msg, "none") != 0) /* NOTRANSLATE */
-	     snprintf(msg, maxtextlength, "QUIT :%s", gdata.quit_msg); /* NOTRANSLATE */
+             snprintf(msg, maxtextlength, "QUIT :%s", gdata.quit_msg); /* NOTRANSLATE */
            else
-	     snprintf(msg, maxtextlength, "QUIT"); /* NOTRANSLATE */
+             snprintf(msg, maxtextlength, "QUIT"); /* NOTRANSLATE */
          }
        for (ss=0; ss<gdata.networks_online; ss++)
          {
@@ -1276,9 +1283,9 @@ char* getstatusline(char *str, size_t len)
                netq,
                srvq,
                xdccsent/1024,
-               ((float)xdccsent)/XDCC_SENT_SIZE/1024.0,
+               ((float)xdccsum)/XDCC_SENT_SIZE/1024.0,
                ((float)xdccrecv)/XDCC_SENT_SIZE/1024.0,
-               ((float)xdccsum)/XDCC_SENT_SIZE/1024.0);
+               ((float)xdccsent)/XDCC_SENT_SIZE/1024.0);
     }
   else
     {
@@ -1524,38 +1531,10 @@ void initvars(void)
   }
   return;
 }
-   
-void startupiroffer(void) {
-   char *tempstr23;
-#if !defined(NO_SETUID)
-   uid_t runasuid = 0;
-   gid_t runasgid = 0;
-   gid_t *groups = NULL;
-   int ngroups = 0;
-   int ii;
-#endif
+
+void set_signal_handler(void)
+{
    struct sigaction sa;
-   struct rlimit rlim;
-   int callval;
-   unsigned int ss;
-   unsigned int save;
-   
-   updatecontext();
-   
-   srand((unsigned int)( (getpid()*5000) + (gdata.curtime%5000) ));
-   
-   if (!gdata.background) {
-      initscreen(1, 1);
-      gotobot();
-      gototop();
-      }
-   
-   printf("\n");
-   if (!gdata.background && !gdata.nocolor) printf(IRVT_COLOR_YELLOW);
-   printf("Welcome to iroffer-dinoex - " "https://iroffer.net/" FEATURES "\n"
-          "Version " VERSIONLONG "\n");
-   if (!gdata.background && !gdata.nocolor) printf(IRVT_COLOR_RESET);
-   printf("\n");
    
    /* signal handling */
    bzero(&sa, sizeof(sa));
@@ -1584,8 +1563,44 @@ void startupiroffer(void) {
    signal(SIGALRM,SIG_IGN);
    signal(SIGHUP,SIG_IGN);
    signal(SIGTSTP,SIG_IGN);
+}
+
+void startupiroffer(void)
+{
+   char *tempstr23;
+#if !defined(NO_SETUID)
+   uid_t runasuid = 0;
+   gid_t runasgid = 0;
+   gid_t *groups = NULL;
+   int ngroups = 0;
+   int ii;
+#endif
+   struct rlimit rlim;
+   int callval;
+   unsigned int ss;
+   unsigned int save;
    
-   printf("** iroffer-dinoex is distributed under the GNU General Public License.\n"
+   updatecontext();
+   
+   srand((unsigned int)( (getpid()*5000) + (gdata.curtime%5000) ));
+   
+   if (!gdata.background) {
+      initscreen(1, 1);
+      gotobot();
+      gototop();
+      }
+   
+   printf("\n");
+   if (!gdata.background && !gdata.nocolor) printf(IRVT_COLOR_YELLOW);
+   printf("Welcome to " "iroffer-dinoex" " - " "https://iroffer.net/" FEATURES "\n"
+          "Version " VERSIONLONG "\n");
+   if (!gdata.background && !gdata.nocolor) printf(IRVT_COLOR_RESET);
+   printf("\n");
+   
+   /* signal handling */
+   set_signal_handler();
+   
+   printf("** " "iroffer-dinoex" " is distributed under the GNU General Public License.\n"
           "**    please see the LICENSE for more information.\n");
 
    printf("\n** Starting up...\n");
@@ -1627,7 +1642,7 @@ void startupiroffer(void) {
       if( chroot( gdata.chrootdir ) < 0 ) {
         outerror( OUTERROR_TYPE_CRASH, "Can't chroot: %s", strerror(errno));
       }
-      if( chdir("/") < 0 ) {
+      if( chdir("/") < 0 ) { /* NOTRANSLATE */
         outerror( OUTERROR_TYPE_CRASH, "Can't chdir: %s", strerror(errno) );
       }
    }
@@ -1671,12 +1686,12 @@ void startupiroffer(void) {
      {
        outerror(
 #if BLOCKROOT && !defined(_OS_CYGWIN)
-		OUTERROR_TYPE_CRASH,
+                OUTERROR_TYPE_CRASH,
 #else
-		OUTERROR_TYPE_WARN_LOUD,
+                OUTERROR_TYPE_WARN_LOUD,
 #endif
-		"iroffer should not be run as root!"
-		);
+                "iroffer should not be run as root!"
+                );
      }
    
    if (!gdata.background)
@@ -1752,7 +1767,7 @@ void startupiroffer(void) {
    
    getconfig();
    
-   mylog("iroffer-dinoex started " VERSIONLONG FEATURES);
+   mylog("iroffer-dinoex" " started " VERSIONLONG FEATURES);
 
    getos();
    
@@ -1869,7 +1884,7 @@ void createpassword(void) {
    unsigned int saltnum;
    char salt[6], *pwout;
    
-   printf("\niroffer-dinoex " VERSIONLONG "\n"
+   printf("\n" "iroffer-dinoex" " " VERSIONLONG "\n"
           "  Configuration File Password Generator\n"
           "\n"
           "This will take a password of your choosing and encrypt it.\n"
