@@ -1,17 +1,21 @@
-/*      
- * iroffer by David Johnson (PMG) 
- * Copyright (C) 1998-2005 David Johnson 
- * 
+/*
+ * iroffer by David Johnson (PMG)
+ * Copyright (C) 1998-2005 David Johnson
+ *
  * By using this file, you agree to the terms and conditions set
- * forth in the GNU General Public License.  More information is    
+ * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
- * 
+ *
  * If you received this file without documentation, it can be
  * downloaded from http://iroffer.org/
- * 
+ *
+ * SPDX-FileCopyrightText: 1998-2005 David Johnson
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
  * @(#) iroffer_statefile.c 1.23@(#)
  * pmg@wellington.i202.centerclick.org|src/iroffer_statefile.c|20050313183435|62320
- * 
+ *
  */
 
 /* include the headers */
@@ -149,7 +153,7 @@ typedef struct
   statefile_uint64_t st_size;
   statefile_uint64_t st_dev;
   statefile_uint64_t st_ino;
-  ir_int32 mtime;
+  ir_uint32 mtime;
   MD5Digest md5sum;
 } statefile_item_md5sum_info32_t;
 
@@ -227,7 +231,7 @@ void write_statefile(void)
     next = (unsigned char*)(&hdr[1]);
     
     length = add_snprintf((char *)next, maxtextlength,
-                          "iroffer-dinoex " VERSIONLONG ", %s", gdata.osstring);
+                          "iroffer-dinoex" " " VERSIONLONG ", %s", gdata.osstring);
     
         create_statefile_hdr(hdr, STATEFILE_TAG_IROFFER_VERSION, sizeof(statefile_hdr_t) + ceiling(length+1, 4));
         write_statefile_item(&bout, data);
@@ -422,15 +426,15 @@ unsigned int read_statefile(void)
       switch (hdr->tag)
         {
         case STATEFILE_TAG_TIMESTAMP:
-          read_statefile_time(hdr, "Timestamp", &timestamp, "Written on");
+          read_statefile_time(hdr, "Written on", &timestamp, "Written on");
           break;
           
         case STATEFILE_TAG_XFR_RECORD:
-          read_statefile_float(hdr, "xfr Record", &(gdata.record), "Record");
+          read_statefile_float(hdr, "xfr Record", &(gdata.record), "xfr Record");
           break;
           
         case STATEFILE_TAG_SENT_RECORD:
-          read_statefile_float(hdr, "sent Record", &(gdata.sentrecord), "Bandwidth Record");
+          read_statefile_float(hdr, "Bandwidth Record", &(gdata.sentrecord), "Bandwidth Record");
           break;
           
         case STATEFILE_TAG_TOTAL_SENT:
@@ -467,7 +471,7 @@ unsigned int read_statefile(void)
                           "  [Written by %s]", iroffer_version);
                 }
               iroffer_now = mycalloc(maxtextlength);
-              snprintf(iroffer_now, maxtextlength, "iroffer-dinoex " VERSIONLONG ", %s", gdata.osstring);
+              snprintf(iroffer_now, maxtextlength, "iroffer-dinoex" " " VERSIONLONG ", %s", gdata.osstring);
               if (strcmp(iroffer_version, iroffer_now) != 0)
                 {
                   ++save;
@@ -672,7 +676,7 @@ unsigned int read_statefile(void)
                     break;
                     
                   default:
-                    read_statefile_unknown_tag(ihdr, "XDCC" );
+                    read_statefile_unknown_tag(ihdr, "XDCCS" );
                   }
                 hdr->length -= ceiling(ihdr->length, 4);
                 ihdr = (statefile_hdr_t*)(((char*)ihdr) + ceiling(ihdr->length, 4));
@@ -680,7 +684,7 @@ unsigned int read_statefile(void)
             
             if ((!xd->file) || (!xd->desc))
               {
-                read_statefile_incomplete_tag("XDCC" );
+                read_statefile_incomplete_tag("XDCCS" );
                 mydelete(xd->file);
                 mydelete(xd->desc);
                 mydelete(xd->note);
