@@ -1,17 +1,21 @@
-/*      
- * iroffer by David Johnson (PMG) 
- * Copyright (C) 1998-2005 David Johnson 
- * 
+/*
+ * iroffer by David Johnson (PMG)
+ * Copyright (C) 1998-2005 David Johnson
+ *
  * By using this file, you agree to the terms and conditions set
- * forth in the GNU General Public License.  More information is    
+ * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
- * 
+ *
  * If you received this file without documentation, it can be
  * downloaded from http://iroffer.org/
- * 
+ *
+ * SPDX-FileCopyrightText: 1998-2005 David Johnson
+ * SPDX-FileCopyrightText: 2004-2021 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
  * @(#) iroffer_transfer.c 1.105@(#)
  * pmg@wellington.i202.centerclick.org|src/iroffer_transfer.c|20050116225153|54665
- * 
+ *
  */
 
 /* include the headers */
@@ -215,7 +219,7 @@ void t_transfersome (transfer * const t)
               gdata.transfermethod++;
               return;
             }
-          else if (howmuch < 0 && errno != EAGAIN)
+          else if ((howmuch < 0) && (errno != EAGAIN) && (errno != EINTR))
             {
               t_closeconn(t,"Unable to transfer data",errno);
               return;
@@ -250,7 +254,7 @@ void t_transfersome (transfer * const t)
               gdata.transfermethod++;
               return;
             }
-          else if ((jj < 0) && (errno != EAGAIN))
+          else if ((jj < 0) && (errno != EAGAIN) && (errno != EINTR))
             {
               t_closeconn(t,"Unable to transfer data",errno);
               return;
@@ -289,7 +293,7 @@ void t_transfersome (transfer * const t)
           
           howmuch = read(t->xpack->file_fd, dataptr, attempt);
           
-          if (howmuch < 0 && errno != EAGAIN)
+          if ((howmuch < 0) && (errno != EAGAIN) && (errno != EINTR))
             {
               int errno2 = errno;
               outerror(OUTERROR_TYPE_WARN,"Can't read data from file '%s': %s",
@@ -306,7 +310,7 @@ void t_transfersome (transfer * const t)
           
           howmuch2 = send(t->con.clientsocket, dataptr, howmuch, MSG_NOSIGNAL);
           
-          if (howmuch2 < 0 && errno != EAGAIN)
+          if ((howmuch2 < 0) && (errno != EAGAIN) && (errno != EINTR))
             {
               t_closeconn(t,"Connection Lost",errno);
               return;
@@ -421,7 +425,7 @@ void t_transfersome (transfer * const t)
           
           howmuch2 = send(t->con.clientsocket, dataptr, howmuch, MSG_NOSIGNAL);
           
-          if (howmuch2 < 0 && errno != EAGAIN)
+          if ((howmuch2 < 0) && (errno != EAGAIN) && (errno != EINTR))
             {
               t_closeconn(t,"Connection Lost",errno);
               return;
@@ -855,7 +859,7 @@ void t_checkminspeed(transfer * const t) {
        
        queue_punish_abuse("You are being punished for your slowness", t->net, t->nick);
        
-       hostmask = to_hostmask( "*", t->hostname);
+       hostmask = to_hostmask( "*", t->hostname); /* NOTRANSLATE */
        ignore = get_ignore(hostmask);
        mydelete(hostmask);
        ignore->flags |= IGN_IGNORING;
