@@ -1,17 +1,21 @@
 /*
- * iroffer by David Johnson (PMG) 
- * Copyright (C) 1998-2005 David Johnson 
- * 
+ * iroffer by David Johnson (PMG)
+ * Copyright (C) 1998-2005 David Johnson
+ *
  * By using this file, you agree to the terms and conditions set
- * forth in the GNU General Public License.  More information is    
+ * forth in the GNU General Public License.  More information is
  * available in the LICENSE file.
- * 
+ *
  * If you received this file without documentation, it can be
  * downloaded from http://iroffer.org/
- * 
+ *
+ * SPDX-FileCopyrightText: 1998-2005 David Johnson
+ * SPDX-FileCopyrightText: 2004-2023 Dirk Meyer
+ * SPDX-License-Identifier: GPL-2.0-only
+ *
  * @(#) iroffer_utilities.c 1.205@(#)
  * pmg@wellington.i202.centerclick.org|src/iroffer_utilities.c|20051123201144|35346
- * 
+ *
  */
 
 /* include the headers */
@@ -26,6 +30,7 @@
 #include "dinoex_irc.h"
 #include "dinoex_config.h"
 #include "dinoex_main.h"
+#include "dinoex_ssl.h"
 #include "dinoex_misc.h"
 
 
@@ -537,7 +542,7 @@ static void meminfo_grow(int grow)
   newmeminfo[0].ptr          = newmeminfo;
   newmeminfo[0].alloctime    = gdata.curtime;
   newmeminfo[0].size         = len;
-  newmeminfo[0].src_func     = __FUNCTION__;
+  newmeminfo[0].src_func     = __extension__ __FUNCTION__;
   newmeminfo[0].src_file     = __FILE__;
   newmeminfo[0].src_line     = __LINE__;
   
@@ -1071,7 +1076,6 @@ void dumpgdata(void)
             iter->con.remoteaddr);
   gdata_iter_print_string(nick);
   gdata_irlist_iter_end;
-  gdata_print_int(num_dccchats);
 
   gdata_print_number_cast("%d",curtime,int);
   
@@ -1136,7 +1140,7 @@ void dumpgdata(void)
   gdata_iter_print_number_cast("%d", st_ino, int);
   gdata_iter_print_number_cast("%d", xtime, int);
   dump_line("  : ptr=%p gets=%d minspeed=%.1f maxspeed=%.1f st_size=%" LLPRINTFMT "d",
-          iter,
+          (void *)iter,
           iter->gets,
           iter->minspeed,
           iter->maxspeed,
@@ -1169,7 +1173,7 @@ void dumpgdata(void)
       {
         dump_line(
                 "  : ptr=%p ref_count=%d mmap_ptr=%p mmap_offset=0x%.8" LLPRINTFMT "X mmap_size=0x%.8" LLPRINTFMT "X",
-                iter2,
+                (void *)iter2,
                 iter2->ref_count,
                 iter2->mmap_ptr,
                 (ir_uint64)(iter2->mmap_offset),
@@ -1184,7 +1188,7 @@ void dumpgdata(void)
   gdata_iter_print_string(hostname);
   dump_line(
           "  : xpack=%p queuedtime=%ld",
-          iter->xpack,
+          (void *)iter->xpack,
           (long)iter->queuedtime);
   dump_line("  : restrictsend_bad=%ld" , (long)iter->restrictsend_bad );
   dump_line("  : net=%d", iter->net + 1 );
@@ -1195,7 +1199,7 @@ void dumpgdata(void)
   gdata_iter_print_string(hostname);
   dump_line(
           "  : xpack=%p queuedtime=%ld",
-          iter->xpack,
+          (void *)iter->xpack,
           (long)iter->queuedtime);
   dump_line("  : restrictsend_bad=%ld" , (long)iter->restrictsend_bad );
   dump_line("  : net=%d", iter->net + 1 );
@@ -1222,7 +1226,7 @@ void dumpgdata(void)
           (long)iter->con.lastcontact,
           (long)iter->con.connecttime,
           iter->lastspeed,
-          iter->xpack);
+          (void *)iter->xpack);
   dump_line(
           "  : listenport=%d local%s remote%s",
           iter->con.localport,
@@ -1230,7 +1234,7 @@ void dumpgdata(void)
           iter->con.remoteaddr);
   dump_line("  : restrictsend_bad=%ld" , (long)iter->restrictsend_bad );
 #ifdef HAVE_MMAP
-  dump_line("  : mmap_info=%p", iter->mmap_info);
+  dump_line("  : mmap_info=%p", (void *)iter->mmap_info);
 #endif
   /* severaddress */
   gdata_iter_print_string(nick);
@@ -1280,7 +1284,7 @@ void dumpgdata(void)
   gdata_iter_print_number_cast("%u",listen_time,unsigned int);
   gdata_irlist_iter_end;
   
-  gdata_print_number("%p", md5build.xpack);
+  gdata_print_number_cast("%p", md5build.xpack, void *);
   gdata_print_int(md5build.file_fd);
   
   /* meminfo */
@@ -1909,8 +1913,8 @@ void* irlist_remove(irlist_t *list, void *item)
   
   iitem->next = NULL;
   
+  assert(list->size > 0);
   list->size--;
-  assert(list->size >= 0);
   
   if (next)
     {
@@ -1995,8 +1999,6 @@ unsigned int irlist_size(const irlist_t *list)
 {
   updatecontext();
   
-  assert(list->size >= 0);
-  
   return list->size;
 }
 
@@ -2264,15 +2266,31 @@ int ir_boutput_attempt_flush(ir_boutput_t *bout)
   
   while ((segment = irlist_get_head(&bout->segments)))
     {
-      int retval;
+      int retval = 0;
       
       assert(segment->begin <= segment->end);
       assert(segment->begin <= IR_BOUTPUT_SEGMENT_SIZE);
       assert(segment->end <= IR_BOUTPUT_SEGMENT_SIZE);
       
-      retval = write(bout->fd,
-                     segment->buffer + segment->begin,
-                     segment->end - segment->begin);
+      if (bout->flags & BOUTPUT_SSL)
+        {
+#ifdef USE_OPENSSL
+          retval = chat_write_ssl(bout->sslp,
+                                  segment->buffer + segment->begin,
+                                  segment->end - segment->begin);
+#endif /* USE_OPENSSL */
+#ifdef USE_GNUTLS
+          retval = chat_write_tls(bout->tlsp,
+                                  segment->buffer + segment->begin,
+                                  segment->end - segment->begin);
+#endif /* USE_GNUTLS */
+        }
+      else
+        {
+          retval = write(bout->fd,
+                         segment->buffer + segment->begin,
+                         segment->end - segment->begin);
+        }
       
       if ((retval < 0) && (errno != EAGAIN))
         {
